## Main final


filestem <- 'C:\\Users\\lynng\\'

## ---------------------------------------------------------------------------
## Combine density and trait data
## ---------------------------------------------------------------------------

## Functions needed
source(paste(filestem, 'IGB\\Toni_Klauschies\\Project3_ExperimentNDFD\\scripts\\Function_RTD.R', sep = ""))

## Read data
## source(paste(filestem, 'IGB\\Toni_Klauschies\\Project3_ExperimentNDFD\\scripts\\ReadingData.R', sep = "")) ## uncleaned data
source(paste(filestem, 'pathway\\Data_Klauschies_Govaert.R', sep = ""))

## checking data
head(dat.final)
dat.final$Salinity <- factor(as.character(dat.final$Salinity), levels = c(0.0, 0.75, 1.50, 3.00))

## Remove sample 118 at T8
pos.118 <- which(dat.final$Time == 8 & dat.final$ID == 118)
dat.final <- dat.final[-pos.118,]

## ---------------------------------------------------------------------------
## Get unique trait data
## ---------------------------------------------------------------------------

trait.final.maxdens <- readRDS(paste(filestem, 'IGB\\Toni_Klauschies\\Project3_ExperimentNDFD\\Data\\Trait_final_maxdens.RData', sep=""))

## Remove some dots that have mean_aspect ratio larger than 4
pos.4 <- which(trait.final.maxdens$mean_ar > 4)
trait.final.maxdens <- trait.final.maxdens[-pos.4,]

## there is a paramecium with mean_area of 500, delete
pos.500 <- which(trait.final.maxdens$mean_area < 600 & trait.final.maxdens$Species == 'Pau')
trait.final.maxdens <- trait.final.maxdens[-pos.500,]

## calculate the mean values for each ID and time point
cat.trait <- paste(trait.final.maxdens$ID, trait.final.maxdens$Species, trait.final.maxdens$Salinity, trait.final.maxdens$Temperature,
			trait.final.maxdens$Replicate, trait.final.maxdens$Date, trait.final.maxdens$Time, trait.final.maxdens$predicted_species)
tt.mean <- apply(trait.final.maxdens[,c(4,6,8,10,12, 14, 19:22)], 2, function(y) tapply(y, cat.trait, function(x) mean(x, na.rm=T)))
tt.sd <- apply(trait.final.maxdens[,c(4,6,8,10,12, 14, 19:22)], 2, function(y) tapply(y, cat.trait, function(x) sd(x, na.rm=T)))
tt.n <- apply(trait.final.maxdens[,c(4,6,8,10,12, 14, 19:22)], 2, function(y) tapply(y, cat.trait, function(x) length(x)))

test. <- table(paste(trait.final.maxdens$ID, trait.final.maxdens$Time))

trait.mean <- cbind(RTD(tt.mean), tt.mean, tt.sd, tt.n[,1])
colnames(trait.mean)[1:8] <- c('ID', 'Species', 'Salinity', 'Temperature', 'Replicate', 'Date', 'Time', 'predicted_species')
colnames(trait.mean)[19:28] <- paste('sd_', colnames(trait.mean)[19:28], sep='')
colnames(trait.mean)[29] <- 'n.'

## ---------------------------------------------------------------------------
## calculate the mean traits for each combination for each replicate
## ---------------------------------------------------------------------------
## Plot dynamics over time
time. <- unique(dat.final$Time)
sal. <- c(0, 0.75, 1.5, 3)
temp. <- c(20, 22, 24, 26)

col.mean <- trait.mean[trait.mean$Species == 'Col',]
pau.mean <- trait.mean[trait.mean$Species == 'Pau',]
PC.col.mean <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Col',]
PC.pau.mean <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Pau',]

traits. <- colnames(trait.mean)[9:29]

trait.mean$act.time <- as.numeric(as.character(trait.mean$Date)) - min(as.numeric(as.character(trait.mean$Date)))

## ---------------------------------------------------------------------------
## Calculate the density
## ---------------------------------------------------------------------------

## total number of detected cells per time point
## Calculate densities by taking average individuals per video
dat.growth <- dat.final

pos.4 <- which(dat.growth$mean_ar > 4)
dat.growth <- dat.growth[-pos.4,]

pos.600 <- which(dat.final$Species == 'Pau' & dat.final$mean_area < 600)
dat.final <- dat.final[-pos.600,]

dens.cat <- paste(dat.growth$ID, dat.growth$Species, dat.growth$Culture, dat.growth$Salinity, 
			dat.growth$Temperature, dat.growth$Replicate, dat.growth$Date, dat.growth$Time, dat.growth$True.date, dat.growth$predicted_species)
dens. <- tapply(dat.growth$N_frames, dens.cat, function(x) (sum(x)/250)*(1000/36.125)) ## per mL

## Make a data set
dens.dat <- cbind(RTD(dens.), dens.)
colnames(dens.dat) <- c('ID', 'Species', 'Culture', 'Salinity', 'Temperature', 'Replicate', 'Date', 'Time', 'True.date', 'predicted_species', 'density')

## combine this data set with the trait data set
## we can do so using ID and time which are unique

traits. <- matrix('NA', nrow = nrow(dens.dat), ncol = 21)
colnames(traits.) <- colnames(trait.mean)[9:29]

dens.dat <- cbind(dens.dat, traits.)

for(dd in 1:nrow(dens.dat)){
	which.ID <- dens.dat$ID[dd]
	which.time <- dens.dat$Time[dd]
	which.predspec <- dens.dat$predicted_species[dd]

	tm. <- trait.mean[trait.mean$ID == which.ID & trait.mean$Time == which.time & trait.mean$predicted_species == which.predspec,9:29]
	if(nrow(tm.) != 0){
		dens.dat[dd,12:32] <- trait.mean[trait.mean$ID == which.ID & trait.mean$Time == which.time & trait.mean$predicted_species == which.predspec,9:29]
	}		
}
## there is still an issue, because the maximum density doesn't take into account whether it's pau or col
## so some densities will not have a trait value if the species didn't appear on the maximum frame
## perhaps these we can replace with the trait mean of the final trait data ? 
pos.na <- which(is.na(dens.dat$mean_area))

## add a variable actual time
dens.dat$act.time <- as.numeric(as.character(dens.dat$Date)) - min(as.numeric(as.character(dens.dat$Date)))

## ---------------------------------------------------------------------------
## General effect of temperature, salinity and competition on density dynamics
## ---------------------------------------------------------------------------
## Including density and trait in the different gams

## We remove salinity 3 data due to incomplete data
pos.sal3 <- which(dens.dat$Salinity == 3)
dens.dat2 <- dens.dat[-pos.sal3,]

dens.col2 <- dens.dat2[dens.dat2$predicted_species == 'Col',]
dens.pau2 <- dens.dat2[dens.dat2$predicted_species == 'Pau',]

library(mgcv)

dens. <- log(as.numeric(as.character(dens.col2$density)))
time. <- as.numeric(as.character(dens.col2$act.time))
repl. <- as.factor(as.character(dens.col2$Replicate))
area. <- as.numeric(as.character(dens.col2$mean_area))

SALT. <- as.factor(as.character(dens.col2$Salinity))
TEMP. <- as.factor(as.character(dens.col2$Temperature))
COMP. <- as.factor(as.character(dens.col2$Species))

gam.col2 <- gamm(dens. ~ s(time.) + s(area.) + SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))
summary(gam.col2$lme)

gam.col1 <- gamm(dens. ~ s(time.) + s(area.) + SALT.*TEMP.*COMP., random = list(repl.= ~1))
summary(gam.col1)

anova(gam.col1$lme, gam.col2$lme)

shapiro.test(residuals(gam.col2$lme))

## Paramecium
dens. <- log(as.numeric(as.character(dens.pau2$density)))
time. <- as.numeric(as.character(dens.pau2$act.time))
repl. <- as.numeric(as.character(dens.pau2$Replicate))
area. <- as.numeric(as.character(dens.pau2$mean_area))

SALT. <- as.factor(as.character(dens.pau2$Salinity))
TEMP. <- as.factor(as.character(dens.pau2$Temperature))
COMP. <- as.factor(as.character(dens.pau2$Species))

gam.pau1 <- gamm(dens. ~ s(time.) + s(area.) + SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))
gam.pau2 <- gamm(dens. ~ s(time.) + s(area.) + SALT.*TEMP.*COMP., random = list(repl.= ~1))

anova(gam.pau2$lme, gam.pau1$lme)

summary(gam.pau1$lme)
summary(gam.pau2$lme)

shapiro.test(residuals(gam.pau1$lme))


## ---------------------------------------------------------------------------
## General effect of temperature, salinity and competition on trait dynamics
## ---------------------------------------------------------------------------
## Include density in the different gams

dens. <- as.numeric(as.character(dens.col2$density))
time. <- as.numeric(as.character(dens.col2$act.time))
repl. <- as.factor(as.character(dens.col2$Replicate))
area. <- as.numeric(as.character(dens.col2$mean_area))

SALT. <- as.factor(as.character(dens.col2$Salinity))
TEMP. <- as.factor(as.character(dens.col2$Temperature))
COMP. <- as.factor(as.character(dens.col2$Species))

gam.area.col1 <- gamm(area. ~ s(time.) + s(dens.) + SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))
gam.area.col2 <- gamm(area. ~ s(time.) + s(dens.) + SALT.*TEMP.*COMP., random = list(repl.= ~1))

anova(gam.area.col2$lme, gam.area.col1$lme)

summary(gam.area.col1$lme)

shapiro.test(residuals(gam.area.col.1$lme))

## Paramecium
dens. <- as.numeric(as.character(dens.pau2$density))
time. <- as.numeric(as.character(dens.pau2$act.time))
repl. <- as.factor(as.character(dens.pau2$Replicate))
area. <- as.numeric(as.character(dens.pau2$mean_area))

SALT. <- as.factor(as.character(dens.pau2$Salinity))
TEMP. <- as.factor(as.character(dens.pau2$Temperature))
COMP. <- as.factor(as.character(dens.pau2$Species))

gam.area.pau1 <- gamm(area. ~ s(time.) + s(dens.) + SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))
gam.area.pau2 <- gamm(area. ~ s(time.) + s(dens.) + SALT.*TEMP.*COMP., random = list(repl.= ~1))

anova(gam.area.pau2$lme, gam.area.pau1$lme)

summary(gam.area.pau2$lme)
summary(gam.area.pau1$lme)

shapiro.test(residuals(gam.area.pau2$lme))

## Cell shape
dens. <- as.numeric(as.character(dens.col2$density))
time. <- as.numeric(as.character(dens.col2$act.time))
repl. <- as.factor(as.character(dens.col2$Replicate))
ar. <- as.numeric(as.character(dens.col2$mean_ar))

SALT. <- as.factor(as.character(dens.col2$Salinity))
TEMP. <- as.factor(as.character(dens.col2$Temperature))
COMP. <- as.factor(as.character(dens.col2$Species))

gam.ar.col1 <- gamm(ar. ~ s(time.) + s(dens.) + SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))
gam.ar.col2 <- gamm(ar. ~ s(time.) + s(dens.) + SALT.*TEMP.*COMP., random = list(repl.= ~1))

anova(gam.ar.col2$lme, gam.ar.col1$lme)

summary(gam.ar.col1$lme)

shapiro.test(residuals(gam.ar.col1$lme))

## Paramecium
dens. <- as.numeric(as.character(dens.pau2$density))
time. <- as.numeric(as.character(dens.pau2$act.time))
repl. <- as.factor(as.character(dens.pau2$Replicate))
ar. <- as.numeric(as.character(dens.pau2$mean_ar))

SALT. <- as.factor(as.character(dens.pau2$Salinity))
TEMP. <- as.factor(as.character(dens.pau2$Temperature))
COMP. <- as.factor(as.character(dens.pau2$Species))

gam.ar.pau1 <- gamm(ar. ~ s(time.) + s(dens.) + SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))
gam.ar.pau2 <- gamm(ar. ~ s(time.) + s(dens.) + SALT.*TEMP.*COMP., random = list(repl.= ~1))

anova(gam.ar.pau2$lme, gam.ar.pau1$lme)

summary(gam.ar.pau2$lme)
summary(gam.ar.pau1$lme)

shapiro.test(residuals(gam.ar.pau2$lme))


## ---------------------------------------------------------------------------
## Make a plot of the densities -- replicates
## ---------------------------------------------------------------------------

dens.col <- dens.dat[dens.dat$Species == 'Col',]
dens.pau <- dens.dat[dens.dat$Species == 'Pau',]
densPC.col <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Col',]
densPC.pau <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Pau',]

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

## colpidium
par(mfrow = c(4,4))

for(ii in 1:4){

	for(jj in 1:4){
		plot(dens.col$act.time, log(dens.col$density), type = 'n', main = paste('Salinity', sal.lvl[ii]))
		col.tmp <- dens.col[dens.col$Salinity == sal.lvl[ii] & dens.col$Temperature == temp.lvl[jj],]

		rep. <- unique(col.tmp$Replicate)
		for(rr in 1:length(rep.)){
			col.rep <- col.tmp[col.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(col.rep$act.time))+0.1*(jj-1), log(col.rep$density), pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(col.rep)-1)){
				segments(as.numeric(as.character(col.rep$act.time[tt]))+0.1*(jj-1), log(col.rep$density[tt]), as.numeric(as.character(col.rep$act.time[tt+1]))+0.1*(jj-1), log(col.rep$density[tt+1]), col = col.temp[jj])
			}
		}
	}

}


for(ii in 1:4){

	for(jj in 1:4){
		plot(densPC.col$act.time, log(densPC.col$density), type = 'n', main = paste('Salinity', sal.lvl[ii]))
		col.tmp <- densPC.col[densPC.col$Salinity == sal.lvl[ii] & densPC.col$Temperature == temp.lvl[jj],]

		rep. <- unique(col.tmp$Replicate)
		for(rr in 1:length(rep.)){
			col.rep <- col.tmp[col.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(col.rep$act.time))+0.1*(jj-1), log(col.rep$density), pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(col.rep)-1)){
				segments(as.numeric(as.character(col.rep$act.time[tt]))+0.1*(jj-1), log(col.rep$density[tt]), as.numeric(as.character(col.rep$act.time[tt+1]))+0.1*(jj-1), log(col.rep$density[tt+1]), col = col.temp[jj])
			}
		}
	}

}


## Paramecium
for(ii in 1:4){

	for(jj in 1:4){
		plot(dens.pau$act.time, log(dens.pau$density), type = 'n', main = paste('Salinity', sal.lvl[ii]))
		pau.tmp <- dens.pau[dens.pau$Salinity == sal.lvl[ii] & dens.pau$Temperature == temp.lvl[jj],]

		rep. <- unique(pau.tmp$Replicate)
		for(rr in 1:length(rep.)){
			pau.rep <- pau.tmp[pau.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(pau.rep$act.time))+0.1*(jj-1), log(pau.rep$density), pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(pau.rep)-1)){
				segments(as.numeric(as.character(pau.rep$act.time[tt]))+0.1*(jj-1), log(pau.rep$density[tt]), as.numeric(as.character(pau.rep$act.time[tt+1]))+0.1*(jj-1), log(pau.rep$density[tt+1]), col = col.temp[jj])
			}
		}
	}

}


for(ii in 1:4){

	for(jj in 1:4){
		plot(densPC.pau$act.time, log(densPC.pau$density), type = 'n', main = paste('Salinity', sal.lvl[ii]))
		pau.tmp <- densPC.pau[densPC.pau$Salinity == sal.lvl[ii] & densPC.pau$Temperature == temp.lvl[jj],]

		rep. <- unique(pau.tmp$Replicate)
		for(rr in 1:length(rep.)){
			pau.rep <- pau.tmp[pau.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(pau.rep$act.time))+0.1*(jj-1), log(pau.rep$density), pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(pau.rep)-1)){
				segments(as.numeric(as.character(pau.rep$act.time[tt]))+0.1*(jj-1), log(pau.rep$density[tt]), as.numeric(as.character(pau.rep$act.time[tt+1]))+0.1*(jj-1), log(pau.rep$density[tt+1]), col = col.temp[jj])
			}
		}
	}

}



## ---------------------------------------------------------------------------
## Make a plot of the densities -- average across replicates -- Figure 1
## ---------------------------------------------------------------------------

## Make a plot
dens.col <- dens.dat[dens.dat$Species == 'Col',]
dens.pau <- dens.dat[dens.dat$Species == 'Pau',]
densPC.col <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Col',]
densPC.pau <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Pau',]

mdd.col <- tapply(log(dens.col$density), paste(dens.col$Salinity, dens.col$Temperature, dens.col$Time, dens.col$Date, dens.col$act.time), function(x) mean(x, na.rm=T))
sdd.col <- tapply(log(dens.col$density), paste(dens.col$Salinity, dens.col$Temperature, dens.col$Time, dens.col$Date, dens.col$act.time), function(x) sd(x, na.rm=T))
sed.col <- tapply(log(dens.col$density), paste(dens.col$Salinity, dens.col$Temperature, dens.col$Time, dens.col$Date, dens.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(x)))
nd.col <- tapply(log(dens.col$density), paste(dens.col$Salinity, dens.col$Temperature, dens.col$Time, dens.col$Date, dens.col$act.time), function(x) length(x))
dd.col <- data.frame(cbind(RTD(mdd.col), mdd.col, sdd.col, sed.col, nd.col))
colnames(dd.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'density', 'sd.', 'se.', 'n.')

mdd.pau <- tapply(log(dens.pau$density), paste(dens.pau$Salinity, dens.pau$Temperature, dens.pau$Time, dens.pau$Date, dens.pau$act.time), function(x) mean(x, na.rm=T))
sdd.pau <- tapply(log(dens.pau$density), paste(dens.pau$Salinity, dens.pau$Temperature, dens.pau$Time, dens.pau$Date, dens.pau$act.time), function(x) sd(x, na.rm=T))
sed.pau <- tapply(log(dens.pau$density), paste(dens.pau$Salinity, dens.pau$Temperature, dens.pau$Time, dens.pau$Date, dens.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(x)))
nd.pau <- tapply(log(dens.pau$density), paste(dens.pau$Salinity, dens.pau$Temperature, dens.pau$Time, dens.pau$Date, dens.pau$act.time), function(x) length(x))
dd.pau <- data.frame(cbind(RTD(mdd.pau), mdd.pau, sdd.pau, sed.pau, nd.pau))
colnames(dd.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'density', 'sd.', 'se.', 'n.')


sal.lvl <- c(0, 0.75, 1.5, 3)
temp.lvl <- c(20, 22, 24, 26)

d.max <- max(c(dd.col$density, 10))
col.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.col$act.time, dd.col$density, type = 'n', ylim = c(0.5,9), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		col.tmp <- dd.col[dd.col$Salinity == sal.lvl[ii] & dd.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$density[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density-col.tmp$sd., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density+col.tmp$sd., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.col$act.time, dd.col$sd., type = 'n', ylim = c(0,2), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		col.tmp <- dd.col[dd.col$Salinity == sal.lvl[ii] & dd.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$sd.[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}

p.max <- max(dd.pau$density)
pau.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.pau$act.time, dd.pau$density, type = 'n', ylim = c(0.5,9), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- dd.pau[dd.pau$Salinity == sal.lvl[ii] & dd.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$density[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}
		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density-pau.tmp$sd., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density+pau.tmp$sd., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.pau$act.time, dd.pau$sd., type = 'n', ylim = c(0,2), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		pau.tmp <- dd.pau[dd.pau$Salinity == sal.lvl[ii] & dd.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$sd.[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}

densPC.col <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Col',]
densPC.pau <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Pau',]

mddPC.col <- tapply(log(densPC.col$density), paste(densPC.col$Salinity, densPC.col$Temperature, densPC.col$Time, densPC.col$Date, densPC.col$act.time), function(x) mean(x, na.rm=T))
sddPC.col <- tapply(log(densPC.col$density), paste(densPC.col$Salinity, densPC.col$Temperature, densPC.col$Time, densPC.col$Date, densPC.col$act.time), function(x) sd(x, na.rm=T))
sedPC.col <- tapply(log(densPC.col$density), paste(densPC.col$Salinity, densPC.col$Temperature, densPC.col$Time, densPC.col$Date, densPC.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(x)))
ndPC.col <- tapply(log(densPC.col$density), paste(densPC.col$Salinity, densPC.col$Temperature, densPC.col$Time, densPC.col$Date, densPC.col$act.time), function(x) length(x))
ddPC.col <- data.frame(cbind(RTD(mddPC.col), mddPC.col, sddPC.col, sedPC.col, ndPC.col))
colnames(ddPC.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'density', 'sd.', 'se.', 'n.')

mddPC.pau <- tapply(log(densPC.pau$density), paste(densPC.pau$Salinity, densPC.pau$Temperature, densPC.pau$Time, densPC.pau$Date, densPC.pau$act.time), function(x) mean(x, na.rm=T))
sddPC.pau <- tapply(log(densPC.pau$density), paste(densPC.pau$Salinity, densPC.pau$Temperature, densPC.pau$Time, densPC.pau$Date, densPC.pau$act.time), function(x) sd(x, na.rm=T))
sedPC.pau <- tapply(log(densPC.pau$density), paste(densPC.pau$Salinity, densPC.pau$Temperature, densPC.pau$Time, densPC.pau$Date, densPC.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(x)))
ndPC.pau <- tapply(log(densPC.pau$density), paste(densPC.pau$Salinity, densPC.pau$Temperature, densPC.pau$Time, densPC.pau$Date, densPC.pau$act.time), function(x) length(x))
ddPC.pau <- data.frame(cbind(RTD(mddPC.pau), mddPC.pau, sddPC.pau, sedPC.pau, ndPC.pau))
colnames(ddPC.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'density', 'sd.', 'se.', 'n.')

d.max <- max(log(dd.col$density))
col.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(ddPC.col$act.time, ddPC.col$density, type = 'n', ylim = c(0.5, 9), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- ddPC.col[ddPC.col$Salinity == sal.lvl[ii] & ddPC.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$density[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}	

		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density-col.tmp$sd., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density+col.tmp$sd., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(ddPC.col$act.time, ddPC.col$sd., type = 'n', ylim = c(0,2), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		col.tmp <- ddPC.col[ddPC.col$Salinity == sal.lvl[ii] & ddPC.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$sd.[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}

p.max <- max(dd.pau$density)
pau.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(ddPC.pau$act.time, ddPC.pau$density, type = 'n', ylim = c(0.5,9), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- ddPC.pau[ddPC.pau$Salinity == sal.lvl[ii] & ddPC.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$density[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}

		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density, pch = 21, cex = 1.5, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density-pau.tmp$sd., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density+pau.tmp$sd., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(ddPC.pau$act.time, ddPC.pau$sd., type = 'n', ylim = c(0,2), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		pau.tmp <- ddPC.pau[ddPC.pau$Salinity == sal.lvl[ii] & ddPC.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$sd.[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}

## ---------------------------------------------------------------------------
## Make a plot of the cell size -- replicates
## ---------------------------------------------------------------------------

trait.col <- trait.mean[trait.mean$Species == 'Col',]
trait.pau <- trait.mean[trait.mean$Species == 'Pau',]

traitPC.col <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Col',]
traitPC.pau <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Pau',]


dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

## colpidium
par(mfrow = c(4,4))

for(ii in 1:4){

	for(jj in 1:4){
		plot(trait.col$act.time, trait.col$mean_area, type = 'n', main = paste('Salinity', sal.lvl[ii]))
		col.tmp <- trait.col[trait.col$Salinity == sal.lvl[ii] & trait.col$Temperature == temp.lvl[jj],]

		rep. <- unique(col.tmp$Replicate)
		for(rr in 1:length(rep.)){
			col.rep <- col.tmp[col.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(col.rep$act.time))+0.1*(jj-1), col.rep$mean_area, pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(col.rep)-1)){
				segments(as.numeric(as.character(col.rep$act.time[tt]))+0.1*(jj-1), col.rep$mean_area[tt], as.numeric(as.character(col.rep$act.time[tt+1]))+0.1*(jj-1), col.rep$mean_area[tt+1], col = col.temp[jj])
			}
		}
	}

}


for(ii in 1:4){

	for(jj in 1:4){
		plot(trait.col$act.time, trait.col$mean_area, type = 'n', main = paste('Salinity', sal.lvl[ii]))
		col.tmp <- traitPC.col[traitPC.col$Salinity == sal.lvl[ii] & traitPC.col$Temperature == temp.lvl[jj],]

		rep. <- unique(col.tmp$Replicate)
		for(rr in 1:length(rep.)){
			col.rep <- col.tmp[col.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(col.rep$act.time))+0.1*(jj-1), col.rep$mean_area, pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(col.rep)-1)){
				segments(as.numeric(as.character(col.rep$act.time[tt]))+0.1*(jj-1), col.rep$mean_area[tt], as.numeric(as.character(col.rep$act.time[tt+1]))+0.1*(jj-1), col.rep$mean_area[tt+1], col = col.temp[jj])
			}
		}
	}

}


## paramecium
par(mfrow = c(4,4))
par(mfrow = c(1,4))

for(ii in 1:4){

	for(jj in 1:4){
		plot(trait.pau$act.time, trait.pau$mean_area, type = 'n', main = paste('Salinity', sal.lvl[ii]))
		pau.tmp <- trait.pau[trait.pau$Salinity == sal.lvl[ii] & trait.pau$Temperature == temp.lvl[jj],]

		rep. <- unique(pau.tmp$Replicate)
		for(rr in 1:length(rep.)){
			pau.rep <- pau.tmp[pau.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(pau.rep$act.time))+0.1*(jj-1), pau.rep$mean_area, pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(pau.rep)-1)){
				segments(as.numeric(as.character(pau.rep$act.time[tt]))+0.1*(jj-1), pau.rep$mean_area[tt], as.numeric(as.character(pau.rep$act.time[tt+1]))+0.1*(jj-1), pau.rep$mean_area[tt+1], col = col.temp[jj])
			}
		}
	}

}

pos.2000 <- which(trait.pau$mean_area < 2000)
trait.pau[pos.2000,]

for(ii in 1:4){

	for(jj in 1:4){
		plot(trait.pau$act.time, trait.pau$mean_area, type = 'n', main = paste('Salinity', sal.lvl[ii]))
		pau.tmp <- traitPC.pau[traitPC.pau$Salinity == sal.lvl[ii] & traitPC.pau$Temperature == temp.lvl[jj],]

		rep. <- unique(pau.tmp$Replicate)
		for(rr in 1:length(rep.)){
			pau.rep <- pau.tmp[pau.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(pau.rep$act.time))+0.1*(jj-1), pau.rep$mean_area, pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(pau.rep)-1)){
				segments(as.numeric(as.character(pau.rep$act.time[tt]))+0.1*(jj-1), pau.rep$mean_area[tt], as.numeric(as.character(pau.rep$act.time[tt+1]))+0.1*(jj-1), pau.rep$mean_area[tt+1], col = col.temp[jj])
			}
		}
	}

}

## ---------------------------------------------------------------------------
## Make a plot of the cell size -- averaged across replicates
## ---------------------------------------------------------------------------

trait.col <- trait.mean[trait.mean$Species == 'Col',]
trait.pau <- trait.mean[trait.mean$Species == 'Pau',]

m.area.col <- tapply(trait.col$mean_area, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) mean(x, na.rm=T))
sd.area.col <- tapply(trait.col$mean_area, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) sd(x, na.rm=T))
se.area.col <- tapply(trait.col$mean_area, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
n.area.col <- tapply(trait.col$mean_area, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) length(na.exclude(x)))
dat.area.col <- data.frame(cbind(RTD(m.area.col), m.area.col, sd.area.col, se.area.col, n.area.col))
colnames(dat.area.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_area', 'sd.', 'se.', 'n.')

m.area.pau <- tapply(trait.pau$mean_area, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) mean(x, na.rm=T))
sd.area.pau <- tapply(trait.pau$mean_area, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) sd(x, na.rm=T))
se.area.pau <- tapply(trait.pau$mean_area, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
n.area.pau <- tapply(trait.pau$mean_area, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) length(na.exclude(x)))
dat.area.pau <- data.frame(cbind(RTD(m.area.pau), m.area.pau, sd.area.pau, se.area.pau, n.area.pau))
colnames(dat.area.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_area', 'sd.', 'se.', 'n.')

sal.lvl <- c(0, 0.75, 1.5, 3)
temp.lvl <- c(20, 22, 24, 26)

d.max <- max(c(dat.area.col$mean_area))
col.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dat.area.col$act.time, dat.area.col$mean_area, type = 'n', ylim = c(0,8000), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- dat.area.col[dat.area.col$Salinity == sal.lvl[ii] & dat.area.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$mean_area[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area-col.tmp$se., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area+col.tmp$se., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dat.area.col$act.time, dat.area.col$sd., type = 'n', ylim = c(20,1200), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		col.tmp <- dat.area.col[dat.area.col$Salinity == sal.lvl[ii] & dat.area.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$sd.[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		#pos.na <- which(is.na(yy.))
		#if(length(pos.na) != 0){
		#	yy. <- yy.[-pos.na]
		#	xx. <- xx.[-pos.na]
		#}

		nr. <- nrow(col.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dat.area.pau$act.time, dat.area.pau$mean_area, type = 'n', ylim = c(0,8000), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- dat.area.pau[dat.area.pau$Salinity == sal.lvl[ii] & dat.area.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$mean_area[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area-pau.tmp$se., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area+pau.tmp$se., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dat.area.pau$act.time, dat.area.pau$sd., type = 'n', ylim = c(20,2000), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		pau.tmp <- dat.area.pau[dat.area.pau$Salinity == sal.lvl[ii] & dat.area.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$sd.[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		#pos.na <- which(is.na(yy.))
		#if(length(pos.na) != 0){
		#	yy. <- yy.[-pos.na]
		#	xx. <- xx.[-pos.na]
		#}

		nr. <- nrow(pau.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}

traitPC.col <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Col',]
traitPC.pau <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Pau',]

mPC.area.col <- tapply(traitPC.col$mean_area, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) mean(x, na.rm=T))
sdPC.area.col <- tapply(traitPC.col$mean_area, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) sd(x, na.rm=T))
sePC.area.col <- tapply(traitPC.col$mean_area, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nPC.area.col <- tapply(traitPC.col$mean_area, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) length(na.exclude(x)))
datPC.area.col <- data.frame(cbind(RTD(mPC.area.col), mPC.area.col, sdPC.area.col, sePC.area.col, nPC.area.col))
colnames(datPC.area.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_area', 'sd.', 'se.', 'n.')

mPC.area.pau <- tapply(traitPC.pau$mean_area, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) mean(x, na.rm=T))
sdPC.area.pau <- tapply(traitPC.pau$mean_area, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) sd(x, na.rm=T))
sePC.area.pau <- tapply(traitPC.pau$mean_area, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nPC.area.pau <- tapply(traitPC.pau$mean_area, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) length(na.exclude(x)))
datPC.area.pau <- data.frame(cbind(RTD(mPC.area.pau), mPC.area.pau, sdPC.area.pau, sePC.area.pau, nPC.area.pau))
colnames(datPC.area.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_area', 'sd.', 'se.', 'n.')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(datPC.area.col$act.time, datPC.area.col$mean_area, type = 'n', ylim = c(0, 8000), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- datPC.area.col[datPC.area.col$Salinity == sal.lvl[ii] & datPC.area.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$mean_area[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}	

		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area-col.tmp$se., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_area+col.tmp$se., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(datPC.area.col$act.time, datPC.area.col$sd., type = 'n', ylim = c(20,1200), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		col.tmp <- datPC.area.col[datPC.area.col$Salinity == sal.lvl[ii] & datPC.area.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$sd.[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		#pos.na <- which(is.na(yy.))
		#if(length(pos.na) != 0){
		#	yy. <- yy.[-pos.na]
		#	xx. <- xx.[-pos.na]
		#}

		nr. <- nrow(col.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(datPC.area.pau$act.time, datPC.area.pau$mean_area, type = 'n', ylim = c(0, 8000), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- datPC.area.pau[datPC.area.pau$Salinity == sal.lvl[ii] & datPC.area.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$mean_area[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}	

		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area-pau.tmp$se., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_area+pau.tmp$se., col = col.temp[jj])
	}
}

## plot of std ? 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(datPC.area.pau$act.time, datPC.area.pau$sd., type = 'n', ylim = c(20,2000), main = paste('Salinity', sal.lvl[ii])) #xlim might be modified
	for(jj in 1:4){
		pau.tmp <- datPC.area.pau[datPC.area.pau$Salinity == sal.lvl[ii] & datPC.area.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$sd.[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		#pos.na <- which(is.na(yy.))
		#if(length(pos.na) != 0){
		#	yy. <- yy.[-pos.na]
		#	xx. <- xx.[-pos.na]
		#}

		nr. <- nrow(pau.tmp) #10
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$sd., pch = 21, cex = 2, col = col.temp[jj])
	}
}


## ---------------------------------------------------------------------------
## Make a plot of the cell shape 
## ---------------------------------------------------------------------------

trait.col <- trait.mean[trait.mean$Species == 'Col',]
trait.pau <- trait.mean[trait.mean$Species == 'Pau',]

m.ar.col <- tapply(trait.col$mean_ar, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) mean(x, na.rm=T))
sd.ar.col <- tapply(trait.col$mean_ar, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) sd(x, na.rm=T))
se.ar.col <- tapply(trait.col$mean_ar, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
n.ar.col <- tapply(trait.col$mean_ar, paste(trait.col$Salinity, trait.col$Temperature, trait.col$Time, trait.col$Date, trait.col$act.time), function(x) length(na.exclude(x)))
dat.ar.col <- data.frame(cbind(RTD(m.ar.col), m.ar.col, sd.ar.col, se.ar.col, n.ar.col))
colnames(dat.ar.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_ar', 'sd.', 'se.', 'n.')

m.ar.pau <- tapply(trait.pau$mean_ar, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) mean(x, na.rm=T))
sd.ar.pau <- tapply(trait.pau$mean_ar, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) sd(x, na.rm=T))
se.ar.pau <- tapply(trait.pau$mean_ar, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
n.ar.pau <- tapply(trait.pau$mean_ar, paste(trait.pau$Salinity, trait.pau$Temperature, trait.pau$Time, trait.pau$Date, trait.pau$act.time), function(x) length(na.exclude(x)))
dat.ar.pau <- data.frame(cbind(RTD(m.ar.pau), m.ar.pau, sd.ar.pau, se.ar.pau, n.ar.pau))
colnames(dat.ar.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_ar', 'sd.', 'se.', 'n.')

sal.lvl <- c(0, 0.75, 1.5, 3)
temp.lvl <- c(20, 22, 24, 26)

d.max <- max(c(dat.ar.col$mean_ar))
col.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dat.ar.col$act.time, dat.ar.col$mean_ar, type = 'n', ylim = c(1,3), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- dat.ar.col[dat.ar.col$Salinity == sal.lvl[ii] & dat.ar.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$mean_ar[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar-col.tmp$se., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar+col.tmp$se., col = col.temp[jj])
	}
}

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dat.ar.pau$act.time, dat.ar.pau$mean_ar, type = 'n', ylim = c(1,3), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- dat.ar.pau[dat.ar.pau$Salinity == sal.lvl[ii] & dat.ar.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$mean_ar[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar-pau.tmp$se., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar+pau.tmp$se., col = col.temp[jj])
	}
}

traitPC.col <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Col',]
traitPC.pau <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Pau',]

mPC.ar.col <- tapply(traitPC.col$mean_ar, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) mean(x, na.rm=T))
sdPC.ar.col <- tapply(traitPC.col$mean_ar, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) sd(x, na.rm=T))
sePC.ar.col <- tapply(traitPC.col$mean_ar, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nPC.ar.col <- tapply(traitPC.col$mean_ar, paste(traitPC.col$Salinity, traitPC.col$Temperature, traitPC.col$Time, traitPC.col$Date, traitPC.col$act.time), function(x) length(na.exclude(x)))
datPC.ar.col <- data.frame(cbind(RTD(mPC.ar.col), mPC.ar.col, sdPC.ar.col, sePC.ar.col, nPC.ar.col))
colnames(datPC.ar.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_ar', 'sd.', 'se.', 'n.')

mPC.ar.pau <- tapply(traitPC.pau$mean_ar, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) mean(x, na.rm=T))
sdPC.ar.pau <- tapply(traitPC.pau$mean_ar, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) sd(x, na.rm=T))
sePC.ar.pau <- tapply(traitPC.pau$mean_ar, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nPC.ar.pau <- tapply(traitPC.pau$mean_ar, paste(traitPC.pau$Salinity, traitPC.pau$Temperature, traitPC.pau$Time, traitPC.pau$Date, traitPC.pau$act.time), function(x) length(na.exclude(x)))
datPC.ar.pau <- data.frame(cbind(RTD(mPC.ar.pau), mPC.ar.pau, sdPC.ar.pau, sePC.ar.pau, nPC.ar.pau))
colnames(datPC.ar.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'mean_ar', 'sd.', 'se.', 'n.')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(datPC.ar.col$act.time, datPC.ar.col$mean_ar, type = 'n', ylim = c(1, 3), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- datPC.ar.col[datPC.ar.col$Salinity == sal.lvl[ii] & datPC.ar.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$mean_ar[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}	

		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar-col.tmp$se., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$mean_ar+col.tmp$se., col = col.temp[jj])
	}
}

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(datPC.ar.pau$act.time, datPC.ar.pau$mean_ar, type = 'n', ylim = c(1, 3), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- datPC.ar.pau[datPC.ar.pau$Salinity == sal.lvl[ii] & datPC.ar.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$mean_ar[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}	

		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar-pau.tmp$se., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$mean_ar+pau.tmp$se., col = col.temp[jj])
	}
}


## ---------------------------------------------------------------------------
## Calculate the per-capita growth rate
## gi = (ln(Bt+1) - ln(Bt)) / (t+1 - t)
## ---------------------------------------------------------------------------

id.lvl <- unique(dens.dat$ID)
time.lvl <- unique(dens.dat$Time)

date.lvl <- as.numeric(as.character(unique(dens.dat$Date)))

#time.points <- 0:13

dat.growthrate <- vector()
for(id in 1:length(id.lvl)){
	dat.id <- dens.dat[dens.dat$ID == id.lvl[id],]
	dat.id <- dat.id[dat.id$predicted_species != 'PC',]
	is.comp <- unique(dat.id$Species)

	time.points <- as.numeric(as.character(unique(dat.id$Time)))
	#time.points <- time.points[order(time.points)]

	if(is.comp != 'PC'){
		if(nrow(dat.id) > 1){
		dat.tmp <- vector()
		for(time. in 1:(length(time.points)-1)){
			N. <- log(dat.id$density[dat.id$Time == time.points[time.+1]]) - log(dat.id$density[dat.id$Time == time.points[time.]])
			DN. <- as.numeric(as.character(dat.id$Date[dat.id$Time == time.points[time.+1]])) - as.numeric(as.character(dat.id$Date[dat.id$Time == time.points[time.]]))
			g.BV <- N./DN.

			## construct a new data set that has all the information, and the mean biovolume/area of the two time points
			dat.tmp <- rbind(dat.tmp, c(unique(dat.id$ID), unique(dat.id$Species), unique(dat.id$Salinity), unique(dat.id$Temperature), unique(dat.id$Replicate),
				unique(dat.id$Date[dat.id$Time == time.points[time.]]), unique(dat.id$Time[dat.id$Time == time.points[time.]]), unique(dat.id$predicted_species),
				paste(unique(dat.id$Date[dat.id$Time == time.points[time.]]), '-', unique(dat.id$Date[dat.id$Time == time.points[time.+1]]), sep=""),
				paste(unique(dat.id$Time[dat.id$Time == time.points[time.]]), '-', unique(dat.id$Time[dat.id$Time == time.points[time.+1]]), sep=""), 
				mean(as.numeric(as.character(c(dat.id$density[dat.id$Time == time.points[time.]], dat.id$density[dat.id$Time == time.points[time.+1]])))), 
				mean(as.numeric(as.character(c(dat.id$mean_area[dat.id$Time == time.points[time.]], dat.id$mean_area[dat.id$Time == time.points[time.+1]])))),g.BV))
		}
		dat.growthrate <- rbind(dat.growthrate, dat.tmp)
		} 
	} else {
		id.pau <- dat.id[dat.id$predicted_species == 'Pau',]
		id.col <- dat.id[dat.id$predicted_species == 'Col',]
		if(nrow(dat.id) > 1){
			dat.tmp <- vector()
			for(time. in 1:(length(time.points)-1)){
				t0 <- length(id.pau$density[id.pau$Time == time.points[time.]])
				t1 <- length(id.pau$density[id.pau$Time == time.points[time.+1]])

				if(t0 == 1 & t1 == 1){
					N. <- log(id.pau$density[id.pau$Time == time.points[time.+1]]) - log(id.pau$density[id.pau$Time == time.points[time.]])
					DN. <- as.numeric(as.character(id.pau$Date[id.pau$Time == time.points[time.+1]])) - as.numeric(as.character(id.pau$Date[id.pau$Time == time.points[time.]]))
					g.BV <- N./DN.
				} else {
					g.BV <- m.BV <- NA
				}

				## construct a new data set that has all the information, and the mean biovolume/area of the two time points
				dat.tmp <- rbind(dat.tmp, c(unique(dat.id$ID), unique(dat.id$Species), unique(dat.id$Salinity), unique(dat.id$Temperature), unique(dat.id$Replicate),
					unique(dat.id$Date[dat.id$Time == time.points[time.]]), unique(dat.id$Time[dat.id$Time == time.points[time.]]), 'Pau',
					paste(unique(dat.id$Date[dat.id$Time == time.points[time.]]), '-', unique(dat.id$Date[dat.id$Time == time.points[time.+1]]), sep=""),
					paste(unique(dat.id$Time[dat.id$Time == time.points[time.]]), '-', unique(dat.id$Time[dat.id$Time == time.points[time.+1]]), sep=""), 
					mean(as.numeric(as.character(c(id.pau$density[id.pau$Time == time.points[time.]], id.pau$density[id.pau$Time == time.points[time.+1]]))), na.rm=TRUE), 
					mean(as.numeric(as.character(c(id.pau$mean_area[id.pau$Time == time.points[time.]], id.pau$mean_area[id.pau$Time == time.points[time.+1]]))), na.rm=TRUE), 
					g.BV))
			}
			dat.growthrate <- rbind(dat.growthrate, dat.tmp)	
 
			dat.tmp <- vector()
			for(time. in 1:(length(time.points)-1)){
				t0 <- length(id.col$density[id.col$Time == time.points[time.]])
				t1 <- length(id.col$density[id.col$Time == time.points[time.+1]])

				if(t0 == 1 & t1 == 1){
					N. <- log(id.col$density[id.col$Time == time.points[time.+1]]) - log(id.col$density[id.col$Time == time.points[time.]])
					DN. <- as.numeric(as.character(id.col$Date[id.col$Time == time.points[time.+1]])) - as.numeric(as.character(id.col$Date[id.col$Time == time.points[time.]]))
					g.BV <- N./DN.
				} else {
					g.BV <- m.BV <- NA
				}

				## construct a new data set that has all the information, and the mean biovolume/area of the two time points
				dat.tmp <- rbind(dat.tmp, c(unique(dat.id$ID), unique(dat.id$Species), unique(dat.id$Salinity), unique(dat.id$Temperature), unique(dat.id$Replicate),
					unique(dat.id$Date[dat.id$Time == time.points[time.]]), unique(dat.id$Time[dat.id$Time == time.points[time.]]), 'Col',
					paste(unique(dat.id$Date[dat.id$Time == time.points[time.]]), '-', unique(dat.id$Date[dat.id$Time == time.points[time.+1]]), sep=""),
					paste(unique(dat.id$Time[dat.id$Time == time.points[time.]]), '-', unique(dat.id$Time[dat.id$Time == time.points[time.+1]]), sep=""), 
					mean(as.numeric(as.character(c(id.col$density[id.col$Time == time.points[time.]], id.col$density[id.col$Time == time.points[time.+1]]))), na.rm=TRUE), 
					mean(as.numeric(as.character(c(id.col$mean_area[id.col$Time == time.points[time.]], id.col$mean_area[id.col$Time == time.points[time.+1]]))), na.rm=TRUE), g.BV))
			}
			dat.growthrate <- rbind(dat.growthrate, dat.tmp)
		}
	}
}
		
dat.growthrate <- data.frame(dat.growthrate)
colnames(dat.growthrate) <- c('ID', 'Species', 'Salinity', 'Temperature', 'Replicate', 'Date', 'Time', 'predicted_species', 'diff.date', 'diff.time', 'mean.dens', 'mean.area', 'g.dens')

## ---------------------------------------------------------------------------
## Visualize the per-capita growth rate and test general effects of temp, salt and comp via gams
## ---------------------------------------------------------------------------

dat.growthrate$act.time <- as.numeric(as.character(dat.growthrate$Date)) - min(as.numeric(as.character(dat.growthrate$Date)))

pos.sal3 <- which(dat.growthrate$Salinity == 3)
dat.GR2 <- dat.growthrate[-pos.sal3,]

dat.GR.col2 <- dat.GR2[dat.GR2$predicted_species == 'Col',]
dat.GR.pau2 <- dat.GR2[dat.GR2$predicted_species == 'Pau',]
 
gr. <- as.numeric(as.character(dat.GR.col2$g.dens))
time. <- as.numeric(as.character(dat.GR.col2$act.time))
repl. <- as.factor(as.character(dat.GR.col2$Replicate))
dens. <- as.numeric(as.character(dat.GR.col2$mean.dens))
area. <- as.numeric(as.character(dat.GR.col2$mean.area))

SALT. <- as.factor(as.character(dat.GR.col2$Salinity))
TEMP. <- as.factor(as.character(dat.GR.col2$Temperature))
COMP. <- as.factor(as.character(dat.GR.col2$Species))

gam.gr.col1 <- gamm(gr. ~ s(time.) + s(dens.) + SALT.*TEMP.*COMP., random = list(repl.= ~1))
gam.gr.col2 <- gamm(gr. ~ s(time.) + s(dens.) + SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))

summary(gam.gr.col1$lme)

anova(gam.gr.col1$lme, gam.gr.col2$lme)

shapiro.test(residuals(gam.gr.col2))

gam.gr.col3 <- gamm(gr. ~ s(time.) + s(dens.) + SALT. + TEMP. + COMP., random = list(repl.= ~1))
gam.gr.col3a <- gamm(gr. ~ s(time.) + s(dens.) + SALT.*TEMP. + COMP., random = list(repl.= ~1))
gam.gr.col3b <- gamm(gr. ~ s(time.) + s(dens.)  + SALT. + TEMP.*COMP., random = list(repl.= ~1))
gam.gr.col3c <- gamm(gr. ~ s(time.) + s(dens.) + SALT.*COMP. + TEMP., random = list(repl.= ~1))

anova(gam.gr.col2$lme, gam.gr.col3$lme)
anova(gam.gr.col3$lme, gam.gr.col3a$lme)
anova(gam.gr.col3$lme, gam.gr.col3b$lme)
anova(gam.gr.col3$lme, gam.gr.col3c$lme)

gam.gr.col4 <- gamm(gr. ~ s(time.) + s(dens.) + SALT. + TEMP. + COMP., random = list(repl.= ~1))


summary(gam.gr.col3$lme)

summary(gam.gr.col4$lme)


## Paramecium
gr. <- as.numeric(as.character(dat.GR.pau2$g.dens))
time. <- as.numeric(as.character(dat.GR.pau2$act.time))
repl. <- as.factor(as.character(dat.GR.pau2$Replicate))
dens. <- as.numeric(as.character(dat.GR.pau2$mean.dens))
area. <- as.numeric(as.character(dat.GR.pau2$mean.area))

SALT. <- as.factor(as.character(dat.GR.pau2$Salinity))
TEMP. <- as.factor(as.character(dat.GR.pau2$Temperature))
COMP. <- as.factor(as.character(dat.GR.pau2$Species))

gam.gr.pau1 <- gamm(gr. ~ s(time.) + s(dens.)+ SALT.*TEMP.*COMP., random = list(repl.= ~1))
gam.gr.pau2 <- gamm(gr. ~ s(time.) + s(dens.)+ SALT.*TEMP. + SALT.*COMP. + TEMP.*COMP., random = list(repl.= ~1))
summary(gam.gr.pau2)

anova(gam.gr.pau1$lme, gam.gr.pau2$lme)

shapiro.test(residuals(gam.gr.pau2))

gam.gr.pau3 <- gamm(gr. ~ s(time.) + s(dens.)+ SALT. + TEMP. + COMP., random = list(repl.= ~1))
gam.gr.pau3a <- gamm(gr. ~ s(time.) + s(dens.)+ SALT.*TEMP. + COMP., random = list(repl.= ~1))
gam.gr.pau3b <- gamm(gr. ~ s(time.) + s(dens.)+ SALT. + TEMP.*COMP., random = list(repl.= ~1))
gam.gr.pau3c <- gamm(gr. ~ s(time.) + s(dens.)+ SALT.*COMP. + TEMP., random = list(repl.= ~1))

anova(gam.gr.pau2$lme, gam.gr.pau3$lme)
anova(gam.gr.pau3$lme, gam.gr.pau3a$lme)
anova(gam.gr.pau3$lme, gam.gr.pau3b$lme)
anova(gam.gr.pau3$lme, gam.gr.pau3c$lme)

summary(gam.gr.pau3$lme)


## Make a plot with all the replicates 
##-------------------------------------
dat.GR.col <- dat.growthrate[dat.growthrate$Species == 'Col',]
datPC.GR.col <- dat.growthrate[dat.growthrate$Species == 'PC' & dat.growthrate$predicted_species == 'Col',]
dat.GR.pau <- dat.growthrate[dat.growthrate$Species == 'Pau',]
datPC.GR.pau <- dat.growthrate[dat.growthrate$Species == 'PC' & dat.growthrate$predicted_species == 'Pau',]

par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(dat.GR.col$act.time, dat.GR.col$g.dens, type = 'n', main = paste('Salinity', sal.lvl[ii]))
		col.tmp <- dat.GR.col[dat.GR.col$Salinity == sal.lvl[ii] & dat.GR.col$Temperature == temp.lvl[jj],]

		rep. <- unique(col.tmp$Replicate)
		for(rr in 1:length(rep.)){
			col.rep <- col.tmp[col.tmp$Replicate == rep.[rr],]

			points(as.numeric(as.character(col.rep$act.time))+0.1*(jj-1), as.numeric(as.character(col.rep$g.dens)), pch = 21, cex = 1.5, col = col.temp[jj])

			for(tt in 1:(nrow(col.rep)-1)){
				segments(as.numeric(as.character(col.rep$act.time[tt]))+0.1*(jj-1), as.numeric(as.character(col.rep$g.dens[tt])), as.numeric(as.character(col.rep$act.time[tt+1]))+0.1*(jj-1), as.numeric(as.character(col.rep$g.dens[tt+1])), col = col.temp[jj])
			}
		}
	}
}

## TO DO: 
-- make the plots for competition and the other species 


## For plotting the replicates together
##---------------------------------------------------
dat.GR.col <- dat.growthrate[dat.growthrate$Species == 'Col',]
datPC.GR.col <- dat.growthrate[dat.growthrate$Species == 'PC' & dat.growthrate$predicted_species == 'Col',]
dat.GR.pau <- dat.growthrate[dat.growthrate$Species == 'Pau',]
datPC.GR.pau <- dat.growthrate[dat.growthrate$Species == 'PC' & dat.growthrate$predicted_species == 'Pau',]

mdd.col <- tapply(as.numeric(as.character(dat.GR.col$g.dens)), paste(dat.GR.col$Salinity, dat.GR.col$Temperature, dat.GR.col$Time, dat.GR.col$Date, dat.GR.col$act.time), function(x) mean(x, na.rm=T))
sdd.col <- tapply(as.numeric(as.character(dat.GR.col$g.dens)), paste(dat.GR.col$Salinity, dat.GR.col$Temperature, dat.GR.col$Time, dat.GR.col$Date, dat.GR.col$act.time), function(x) sd(x, na.rm=T))
sed.col <- tapply(as.numeric(as.character(dat.GR.col$g.dens)), paste(dat.GR.col$Salinity, dat.GR.col$Temperature, dat.GR.col$Time, dat.GR.col$Date, dat.GR.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nd.col <- tapply(as.numeric(as.character(dat.GR.col$g.dens)), paste(dat.GR.col$Salinity, dat.GR.col$Temperature, dat.GR.col$Time, dat.GR.col$Date, dat.GR.col$act.time), function(x) length(na.exclude(x)))
dd.col <- data.frame(cbind(RTD(mdd.col), mdd.col, sdd.col, sed.col, nd.col))
colnames(dd.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'g.dens', 'sd.', 'se.', 'n.')

mdd.pau <- tapply(as.numeric(as.character(dat.GR.pau$g.dens)), paste(dat.GR.pau$Salinity, dat.GR.pau$Temperature, dat.GR.pau$Time, dat.GR.pau$Date, dat.GR.pau$act.time), function(x) mean(x, na.rm=T))
sdd.pau <- tapply(as.numeric(as.character(dat.GR.pau$g.dens)), paste(dat.GR.pau$Salinity, dat.GR.pau$Temperature, dat.GR.pau$Time, dat.GR.pau$Date, dat.GR.pau$act.time), function(x) sd(x, na.rm=T))
sed.pau <- tapply(as.numeric(as.character(dat.GR.pau$g.dens)), paste(dat.GR.pau$Salinity, dat.GR.pau$Temperature, dat.GR.pau$Time, dat.GR.pau$Date, dat.GR.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nd.pau <- tapply(as.numeric(as.character(dat.GR.pau$g.dens)), paste(dat.GR.pau$Salinity, dat.GR.pau$Temperature, dat.GR.pau$Time, dat.GR.pau$Date, dat.GR.pau$act.time), function(x) length(na.exclude(x)))
dd.pau <- data.frame(cbind(RTD(mdd.pau), mdd.pau, sdd.pau, sed.pau, nd.pau))
colnames(dd.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'g.dens', 'sd.', 'se.', 'n.')

sal.lvl <- c(0, 0.75, 1.5, 3)
temp.lvl <- c(20, 22, 24, 26)

d.max <- max(c(dd.col$density, 4200))
col.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.col$act.time, dd.col$g.dens, type = 'n', ylim = c(-2,2.5), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- dd.col[dd.col$Salinity == sal.lvl[ii] & dd.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$g.dens[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens-col.tmp$se., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens+col.tmp$se., col = col.temp[jj])
	}
}

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.pau$act.time, dd.pau$g.dens, type = 'n', ylim = c(-2,2.5), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- dd.pau[dd.pau$Salinity == sal.lvl[ii] & dd.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$g.dens[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens-pau.tmp$se., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens+pau.tmp$se., col = col.temp[jj])
	}
}


mdd.col <- tapply(as.numeric(as.character(datPC.GR.col$g.dens)), paste(datPC.GR.col$Salinity, datPC.GR.col$Temperature, datPC.GR.col$Time, datPC.GR.col$Date, datPC.GR.col$act.time), function(x) mean(x, na.rm=T))
sdd.col <- tapply(as.numeric(as.character(datPC.GR.col$g.dens)), paste(datPC.GR.col$Salinity, datPC.GR.col$Temperature, datPC.GR.col$Time, datPC.GR.col$Date, datPC.GR.col$act.time), function(x) sd(x, na.rm=T))
sed.col <- tapply(as.numeric(as.character(datPC.GR.col$g.dens)), paste(datPC.GR.col$Salinity, datPC.GR.col$Temperature, datPC.GR.col$Time, datPC.GR.col$Date, datPC.GR.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nd.col <- tapply(as.numeric(as.character(datPC.GR.col$g.dens)), paste(datPC.GR.col$Salinity, datPC.GR.col$Temperature, datPC.GR.col$Time, datPC.GR.col$Date, datPC.GR.col$act.time), function(x) length(na.exclude(x)))
dd.col <- data.frame(cbind(RTD(mdd.col), mdd.col, sdd.col, sed.col, nd.col))
colnames(dd.col) <- c('Salinity', 'Temperature', 'Time', 'date', 'act.time', 'g.dens', 'sd.', 'se.', 'n.')

mdd.pau <- tapply(as.numeric(as.character(datPC.GR.pau$g.dens)), paste(datPC.GR.pau$Salinity, datPC.GR.pau$Temperature, datPC.GR.pau$Time, datPC.GR.pau$Date, datPC.GR.pau$act.time), function(x) mean(x, na.rm=T))
sdd.pau <- tapply(as.numeric(as.character(datPC.GR.pau$g.dens)), paste(datPC.GR.pau$Salinity, datPC.GR.pau$Temperature, datPC.GR.pau$Time, datPC.GR.pau$Date, datPC.GR.pau$act.time), function(x) sd(x, na.rm=T))
sed.pau <- tapply(as.numeric(as.character(datPC.GR.pau$g.dens)), paste(datPC.GR.pau$Salinity, datPC.GR.pau$Temperature, datPC.GR.pau$Time, datPC.GR.pau$Date, datPC.GR.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(na.exclude(x))))
nd.pau <- tapply(as.numeric(as.character(datPC.GR.pau$g.dens)), paste(datPC.GR.pau$Salinity, datPC.GR.pau$Temperature, datPC.GR.pau$Time, datPC.GR.pau$Date, datPC.GR.pau$act.time), function(x) length(na.exclude(x)))
dd.pau <- data.frame(cbind(RTD(mdd.pau), mdd.pau, sdd.pau, sed.pau, nd.pau))
colnames(dd.pau) <- c('Salinity', 'Temperature', 'Time', 'date', 'act.time', 'g.dens', 'sd.', 'se.', 'n.')

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.col$act.time, dd.col$g.dens, type = 'n', ylim = c(-2,2.5), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- dd.col[dd.col$Salinity == sal.lvl[ii] & dd.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$g.dens[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens-col.tmp$se., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$g.dens+col.tmp$se., col = col.temp[jj])
	}
}

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(dd.pau$act.time, dd.pau$g.dens, type = 'n', ylim = c(-2,2.5), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- dd.pau[dd.pau$Salinity == sal.lvl[ii] & dd.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$g.dens[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}		
		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens-pau.tmp$se., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$g.dens+pau.tmp$se., col = col.temp[jj])
	}
}

## ---------------------------------------------------------------------------
## plot changes in density versus changes in traits
## ---------------------------------------------------------------------------

dens.col <- dens.dat[dens.dat$Species == 'Col',]
dens.pau <- dens.dat[dens.dat$Species == 'Pau',]

densPC.col <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Col',]
densPC.pau <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Pau',]

col.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 14, width = 14)
par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(dens.col$mean_area, dens.col$density, type = 'n', ylim = c(0,5000), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(dens.col$mean_area[dens.col$Salinity == sal.lvl[ii] & dens.col$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(dens.col$density[dens.col$Salinity == sal.lvl[ii] & dens.col$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}


par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(densPC.col$mean_area, densPC.col$density, type = 'n', ylim = c(0,5000), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(densPC.col$mean_area[densPC.col$Salinity == sal.lvl[ii] & densPC.col$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(densPC.col$density[densPC.col$Salinity == sal.lvl[ii] & densPC.col$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}

par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(dens.pau$mean_area, dens.pau$density, type = 'n', ylim = c(0,1000), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(dens.pau$mean_area[dens.pau$Salinity == sal.lvl[ii] & dens.pau$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(dens.pau$density[dens.pau$Salinity == sal.lvl[ii] & dens.pau$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}

par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(densPC.pau$mean_area, densPC.pau$density, type = 'n', ylim = c(0,1000), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(densPC.pau$mean_area[densPC.pau$Salinity == sal.lvl[ii] & densPC.pau$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(densPC.pau$density[densPC.pau$Salinity == sal.lvl[ii] & densPC.pau$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}


## ---------------------------------------------------------------------------
## plot changes in area versus cell shape
## ---------------------------------------------------------------------------

dens.col <- dens.dat[dens.dat$Species == 'Col',]
dens.pau <- dens.dat[dens.dat$Species == 'Pau',]

densPC.col <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Col',]
densPC.pau <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Pau',]

col.temp <- c('blue', 'lightblue', 'pink', 'red')

dev.new(height = 14, width = 14)
par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(dens.col$mean_area, dens.col$mean_ar, type = 'n', ylim = c(1, 3.5), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(dens.col$mean_area[dens.col$Salinity == sal.lvl[ii] & dens.col$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(dens.col$mean_ar[dens.col$Salinity == sal.lvl[ii] & dens.col$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}


par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(densPC.col$mean_area, densPC.col$mean_ar, type = 'n', ylim = c(1, 3.5), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(densPC.col$mean_area[densPC.col$Salinity == sal.lvl[ii] & densPC.col$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(densPC.col$mean_ar[densPC.col$Salinity == sal.lvl[ii] & densPC.col$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}

par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(dens.pau$mean_area, dens.pau$mean_ar, type = 'n', ylim = c(1, 3.5), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(dens.pau$mean_area[dens.pau$Salinity == sal.lvl[ii] & dens.pau$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(dens.pau$mean_ar[dens.pau$Salinity == sal.lvl[ii] & dens.pau$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}

par(mfrow = c(4,4))
for(ii in 1:4){
	for(jj in 1:4){
		plot(densPC.pau$mean_area, densPC.pau$mean_ar, type = 'n', ylim = c(1, 3.5), xlim = c(0, 8000))
		xx. <- as.numeric(as.character(densPC.pau$mean_area[densPC.pau$Salinity == sal.lvl[ii] & densPC.pau$Temperature == temp.lvl[jj]]))
		yy. <- as.numeric(as.character(densPC.pau$mean_ar[densPC.pau$Salinity == sal.lvl[ii] & densPC.pau$Temperature == temp.lvl[jj]]))
		points(xx., yy., col = col.temp[jj])
		print(cor.test(xx., yy.))
	}
}

## ---------------------------------------------------------------------------
## Quantify relative abundances
## ---------------------------------------------------------------------------


dens.comp <- dens.dat[dens.dat$Species == 'PC',]

id.lvl.comp <- unique(dens.comp$ID)

rel.dens.comp <- vector()
for(id in 1:length(id.lvl.comp)){
	id.tmp <- dens.comp[dens.comp$ID == id.lvl.comp[id],]
	time.lvl <- unique(c(id.tmp$Time, 0:12))

	for(tt in 1:length(time.lvl)){
		time.tmp <- id.tmp[id.tmp$Time == time.lvl[tt],]

		if(nrow(time.tmp) > 0){
			time.tmp$rel.dens <- NA
			time.tmp$rel.bv <- NA
			who.there <- intersect(time.tmp$predicted_species, c('Pau', 'Col'))
		}
		if(length(who.there) != 0){		
		if(nrow(time.tmp) == 1){
			time.tmp$rel.dens <- 1
			time.tmp$rel.bv <- 1
			test.tmp <- data.frame(matrix(NA, ncol=ncol(id.tmp), nrow=1))
			colnames(test.tmp) <- colnames(id.tmp)
			test.tmp[,1:9] <- time.tmp[,1:9]
			test.tmp$predicted_species <- setdiff(c('Pau', 'Col'), who.there)
			test.tmp$rel.dens <- 0
			test.tmp$rel.bv <- 0
			time.tmp <- rbind(time.tmp, test.tmp)
		} else {
			if(nrow(time.tmp) == 2 & length(who.there) == 1){
				time.tmp$rel.dens[time.tmp$predicted_species == who.there] <- 1
				time.tmp$rel.bv[time.tmp$predicted_species == who.there] <- 1
				test.tmp <- data.frame(matrix(NA, ncol=ncol(id.tmp), nrow=1))
				colnames(test.tmp) <- colnames(id.tmp)
				test.tmp[,1:9] <- time.tmp[1,1:9]
				test.tmp$predicted_species <- setdiff(c('Pau', 'Col'), who.there)
				test.tmp$rel.dens <- 0
				test.tmp$rel.bv <- 0
				time.tmp <- rbind(time.tmp, test.tmp)
			} else {
				if(nrow(time.tmp) == 2 & length(who.there) == 2){
					#time.tmp$rel.bv[time.tmp$predicted_species == 'Col'] <- time.tmp$BV[time.tmp$predicted_species == 'Col']/(time.tmp$BV[time.tmp$predicted_species == 'Col']+time.tmp$BV[time.tmp$predicted_species == 'Pau'])
					#time.tmp$rel.bv[time.tmp$predicted_species == 'Pau'] <- time.tmp$BV[time.tmp$predicted_species == 'Pau']/(time.tmp$BV[time.tmp$predicted_species == 'Col']+time.tmp$BV[time.tmp$predicted_species == 'Pau'])

					time.tmp$rel.dens[time.tmp$predicted_species == 'Col'] <- time.tmp$density[time.tmp$predicted_species == 'Col']/(time.tmp$density[time.tmp$predicted_species == 'Col']+time.tmp$density[time.tmp$predicted_species == 'Pau'])
					time.tmp$rel.dens[time.tmp$predicted_species == 'Pau'] <- time.tmp$density[time.tmp$predicted_species == 'Pau']/(time.tmp$density[time.tmp$predicted_species == 'Col']+time.tmp$density[time.tmp$predicted_species == 'Pau'])
				} else {
					if(nrow(time.tmp) == 3){
						#time.tmp$rel.bv[time.tmp$predicted_species == 'Col'] <- time.tmp$BV[time.tmp$predicted_species == 'Col']/(time.tmp$BV[time.tmp$predicted_species == 'Col']+time.tmp$BV[time.tmp$predicted_species == 'Pau'])
						#time.tmp$rel.bv[time.tmp$predicted_species == 'Pau'] <- time.tmp$BV[time.tmp$predicted_species == 'Pau']/(time.tmp$BV[time.tmp$predicted_species == 'Col']+time.tmp$BV[time.tmp$predicted_species == 'Pau'])
						#time.tmp$rel.bv[time.tmp$predicted_species == 'PC'] <- 'NA'

						time.tmp$rel.dens[time.tmp$predicted_species == 'Col'] <- time.tmp$density[time.tmp$predicted_species == 'Col']/(time.tmp$density[time.tmp$predicted_species == 'Col']+time.tmp$density[time.tmp$predicted_species == 'Pau'])
						time.tmp$rel.dens[time.tmp$predicted_species == 'Pau'] <- time.tmp$density[time.tmp$predicted_species == 'Pau']/(time.tmp$density[time.tmp$predicted_species == 'Col']+time.tmp$density[time.tmp$predicted_species == 'Pau'])
						#time.tmp$rel.dens[time.tmp$predicted_species == 'PC'] <- 'NA'
					}
				}
			}
		}}
		if(nrow(time.tmp) > 0){
			time.tmp <- time.tmp
		} else {
			test.tmp <- data.frame(matrix(NA, ncol=ncol(id.tmp), nrow=2))
			colnames(test.tmp) <- colnames(id.tmp)
			test.tmp[,1:9] <- rep(c(unique(id.tmp$ID), unique(id.tmp$Species), unique(id.tmp$Culture), unique(id.tmp$Salinity), 
							unique(id.tmp$Temperature), unique(id.tmp$Replicate), NA, time.lvl[tt], NA), 2)
			test.tmp$predicted_species <- c('Col', 'Pau')
			test.tmp$rel.dens <- c(0, 0)
			test.tmp$rel.bv <- c(0, 0)
			time.tmp <- test.tmp
		}
		rel.dens.comp <- rbind(rel.dens.comp, time.tmp)
	}
}

head(rel.dens.comp)
colnames(rel.dens.comp)



## ---------------------------------------------------------------------------
## Create plots of the relative abundances
## ---------------------------------------------------------------------------


library("RColorBrewer")
col.C <- brewer.pal(n = 5, name = 'Blues')
col.P <- brewer.pal(n = 5, name = 'Oranges')

sal.lvl <- c(0, 0.75, 1.5, 3)
temp.lvl <- c(20, 22, 24, 26)

max.d <- 1

dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

dev.new(height = 14, width = 14)
par(mfrow = c(4,4))
for(ii in 1:4){

	for(jj in 1:4){
		time. <- as.numeric(as.character(rel.dens.comp$act.time[rel.dens.comp$Salinity == sal.lvl[ii] & rel.dens.comp$Temperature == temp.lvl[jj] & rel.dens.comp$Species == 'PC']))
		bv. <- rel.dens.comp$rel.dens[rel.dens.comp$Salinity == sal.lvl[ii] & rel.dens.comp$Temperature == temp.lvl[jj] & rel.dens.comp$Species == 'PC']
		plot(time., bv., pch = 21, cex = 1.5, ylab = 'relative density', ylim = c(0,max.d), type = 'n', main = paste('S', sal.lvl[ii], '- T', temp.lvl[jj]))

		for(rr in 1:4){
			xx.C <- as.numeric(as.character(rel.dens.comp$act.time[rel.dens.comp$Salinity == sal.lvl[ii] & rel.dens.comp$Temperature == temp.lvl[jj] & rel.dens.comp$Species == 'PC' & rel.dens.comp$predicted_species == 'Col' & rel.dens.comp$Replicate == rr]))
			yy.C <- rel.dens.comp$rel.dens[rel.dens.comp$Salinity == sal.lvl[ii] & rel.dens.comp$Temperature == temp.lvl[jj] & rel.dens.comp$Species == 'PC' & rel.dens.comp$predicted_species == 'Col' & rel.dens.comp$Replicate == rr]
			lines(xx.C, yy.C, pch = 21, col = 'blue', cex = 2, type = 'o')

			xx.P <- as.numeric(as.character(rel.dens.comp$act.time[rel.dens.comp$Salinity == sal.lvl[ii] & rel.dens.comp$Temperature == temp.lvl[jj] & rel.dens.comp$Species == 'PC' & rel.dens.comp$predicted_species == 'Pau' & rel.dens.comp$Replicate == rr]))
			if(length(which(is.na(xx.P))) != 0){xx.P <- xx.C}	
			yy.P <- rel.dens.comp$rel.dens[rel.dens.comp$Salinity == sal.lvl[ii] & rel.dens.comp$Temperature == temp.lvl[jj] & rel.dens.comp$Species == 'PC' & rel.dens.comp$predicted_species == 'Pau' & rel.dens.comp$Replicate == rr]
			lines(xx.P, yy.P, pch = 21, col = 'red', cex = 2, type = 'o')
		}
	}

}

## Plot replicates together
rel.dens.col <- rel.dens.comp[rel.dens.comp$predicted_species == 'Col',]
rel.dens.pau <- rel.dens.comp[rel.dens.comp$predicted_species == 'Pau',]

reldd.col <- tapply(rel.dens.col$rel.dens, paste(rel.dens.col$Salinity, rel.dens.col$Temperature, rel.dens.col$Time, rel.dens.col$Date, rel.dens.col$act.time), function(x) mean(x, na.rm=T))
relsdd.col <- tapply(rel.dens.col$rel.dens, paste(rel.dens.col$Salinity, rel.dens.col$Temperature, rel.dens.col$Time, rel.dens.col$Date, rel.dens.col$act.time), function(x) sd(x, na.rm=T))
relsed.col <- tapply(rel.dens.col$rel.dens, paste(rel.dens.col$Salinity, rel.dens.col$Temperature, rel.dens.col$Time, rel.dens.col$Date, rel.dens.col$act.time), function(x) sd(x, na.rm=T)/sqrt(length(x)))
relnd.col <- tapply(rel.dens.col$rel.dens, paste(rel.dens.col$Salinity, rel.dens.col$Temperature, rel.dens.col$Time, rel.dens.col$Date, rel.dens.col$act.time), function(x) length(x))
rel.dd.col <- data.frame(cbind(RTD(reldd.col), reldd.col, relsdd.col, relsed.col, relnd.col))
colnames(rel.dd.col) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'rel.dens', 'sd.', 'se.', 'n.')

reldd.pau <- tapply(rel.dens.pau$rel.dens, paste(rel.dens.pau$Salinity, rel.dens.pau$Temperature, rel.dens.pau$Time, rel.dens.pau$Date, rel.dens.pau$act.time), function(x) mean(x, na.rm=T))
relsdd.pau <- tapply(rel.dens.pau$rel.dens, paste(rel.dens.pau$Salinity, rel.dens.pau$Temperature, rel.dens.pau$Time, rel.dens.pau$Date, rel.dens.pau$act.time), function(x) sd(x, na.rm=T))
relsed.pau <- tapply(rel.dens.pau$rel.dens, paste(rel.dens.pau$Salinity, rel.dens.pau$Temperature, rel.dens.pau$Time, rel.dens.pau$Date, rel.dens.pau$act.time), function(x) sd(x, na.rm=T)/sqrt(length(x)))
relnd.pau <- tapply(rel.dens.pau$rel.dens, paste(rel.dens.pau$Salinity, rel.dens.pau$Temperature, rel.dens.pau$Time, rel.dens.pau$Date, rel.dens.pau$act.time), function(x) length(x))
rel.dd.pau <- data.frame(cbind(RTD(reldd.pau), reldd.pau, relsdd.pau, relsed.pau, relnd.pau))
colnames(rel.dd.pau) <- c('Salinity', 'Temperature', 'Time', 'Date', 'act.time', 'rel.dens', 'sd.', 'se.', 'n.')


dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(rel.dd.col$act.time, rel.dd.col$rel.dens, type = 'n', ylim = c(0, 1), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		col.tmp <- rel.dd.col[rel.dd.col$Salinity == sal.lvl[ii] & rel.dd.col$Temperature == temp.lvl[jj],]

		yy. <- col.tmp$rel.dens[order(as.numeric(as.character(col.tmp$act.time)))]
		xx. <- as.numeric(as.character(col.tmp$act.time[order(as.numeric(as.character(col.tmp$act.time)))]))

		nr. <- nrow(col.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}	

		#points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$density, pch = 21, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$rel.dens, pch = 21, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$rel.dens-col.tmp$sd., as.numeric(as.character(col.tmp$act.time))+0.1*(jj-1), col.tmp$rel.dens+col.tmp$sd., col = col.temp[jj])
	}
}


dev.new(height = 5, width = 18)
par(mfrow = c(1,4))
for(ii in 1:4){
	plot(rel.dd.pau$act.time, rel.dd.pau$rel.dens, type = 'n', ylim = c(0, 1), main = paste('Salinity', sal.lvl[ii]))
	for(jj in 1:4){
		pau.tmp <- rel.dd.pau[rel.dd.pau$Salinity == sal.lvl[ii] & rel.dd.pau$Temperature == temp.lvl[jj],]

		yy. <- pau.tmp$rel.dens[order(as.numeric(as.character(pau.tmp$act.time)))]
		xx. <- as.numeric(as.character(pau.tmp$act.time[order(as.numeric(as.character(pau.tmp$act.time)))]))

		nr. <- nrow(pau.tmp) 
		for(ss in 1:(nr.-1)){
			segments(xx.[ss]+0.1*(jj-1), yy.[ss], xx.[ss+1]+0.1*(jj-1), yy.[ss+1], col = col.temp[jj])
		}	

		#points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$density, pch = 22, cex = 2, col = 'white', bg = 'white')
		points(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$rel.dens, pch = 22, cex = 2, col = col.temp[jj])
		segments(as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$rel.dens-pau.tmp$sd., as.numeric(as.character(pau.tmp$act.time))+0.1*(jj-1), pau.tmp$rel.dens+pau.tmp$sd., col = col.temp[jj])
	}
}


## ---------------------------------------------------------------------------
## Check synchrony between dynamics in the competition treatment
## ---------------------------------------------------------------------------

## Gather the data sets
densPC.col <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Col',]
densPC.pau <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Pau',]

traitPC.col <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Col',]
traitPC.pau <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Pau',]

## AREA Between pau and col 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

for(ii in 1:4){

	plot(traitPC.col$mean_area, traitPC.col$mean_area, type = 'n', ylim = c(0, 8000), xlim = c(0, 8000))

	for(jj in 1:4){
		tmp.pau <- traitPC.pau[traitPC.pau$Salinity == sal.lvl[ii] & traitPC.pau$Temperature == temp.lvl[jj],]
		tmp.col <- traitPC.col[traitPC.col$Salinity == sal.lvl[ii] & traitPC.col$Temperature == temp.lvl[jj],]

		for(rr in 1:4){
			rr.pau <- tmp.pau[tmp.pau$Replicate == rr,]
			rr.col <- tmp.col[tmp.col$Replicate == rr,]

			thesame. <- intersect(rr.pau$Time, rr.col$Time)
			pos.pau <- pos.col <- vector()
			for(ss in 1:length(thesame.)){
				pos.pau <- append(pos.pau, which(rr.pau$Time == thesame.[ss]))
				pos.col <- append(pos.col, which(rr.col$Time == thesame.[ss]))
			}

			xx. <- as.numeric(as.character(rr.pau$mean_area[pos.pau]))
			yy. <- as.numeric(as.character(rr.col$mean_area[pos.col]))
			points(xx., yy., cex = 2, pch = 21+(rr-1), col = col.temp[jj])
			print(list(sal.lvl[ii], temp.lvl[jj], cor.test(xx., yy.)))
		}
	}

}


## DENSITY Between pau and col 
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

for(ii in 1:4){

	plot(log(densPC.col$density), log(densPC.col$density), type = 'n', ylim = c(0, 8), xlim = c(0, 8))

	for(jj in 1:4){
		tmp.pau <- densPC.pau[densPC.pau$Salinity == sal.lvl[ii] & densPC.pau$Temperature == temp.lvl[jj],]
		tmp.col <- densPC.col[densPC.col$Salinity == sal.lvl[ii] & densPC.col$Temperature == temp.lvl[jj],]
 
		for(rr in 1:4){
			rr.pau <- tmp.pau[tmp.pau$Replicate == rr,]
			rr.col <- tmp.col[tmp.col$Replicate == rr,]

			thesame. <- intersect(rr.pau$Time, rr.col$Time)
			pos.pau <- pos.col <- vector()
			for(ss in 1:length(thesame.)){
				pos.pau <- append(pos.pau, which(rr.pau$Time == thesame.[ss]))
				pos.col <- append(pos.col, which(rr.col$Time == thesame.[ss]))
			}

			xx. <- as.numeric(as.character(log(rr.pau$density[pos.pau])))
			yy. <- as.numeric(as.character(log(rr.col$density[pos.col])))
			points(xx., yy., cex = 2, pch = 21+(rr-1), col = col.temp[jj])
			print(list(sal.lvl[ii], temp.lvl[jj], cor.test(xx., yy.)))
		}
	}

}


## ---------------------------------------------------------------------------
## Gibert et al. (2022) -- convergent cross mapping
## ---------------------------------------------------------------------------

## Gather the data sets
dens.col <- dens.dat[dens.dat$Species == 'Col',]
dens.pau <- dens.dat[dens.dat$Species == 'Pau',]

densPC.col <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Col',]
densPC.pau <- dens.dat[dens.dat$Species == 'PC' & dens.dat$predicted_species == 'Pau',]

trait.col <- trait.mean[trait.mean$Species == 'Col',]
trait.pau <- trait.mean[trait.mean$Species == 'Pau',]

traitPC.col <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Col',]
traitPC.pau <- trait.mean[trait.mean$Species == 'PC' & trait.mean$predicted_species == 'Pau',]


time.lvl <- unique(dat.final$Time)
sal.lvl <- c(0, 0.75, 1.5, 3)
temp.lvl <- c(20, 22, 24, 26)


library(multispatialCCM)

## Prepare data for CCM
ccm.area.col.list <- ccm.dens.col.list <- list()

## we need to limit to certain time points still!!! 
## if we do not have density at all time points... at least in the beginning

unique(dens.col$Time)

## 1. Colpidium in monoculture
## We will not focus on salinity 3
kk <- 1
for(ii in 1:3){
	for(jj in 1:4){
		tmp.dens <- dens.col[dens.col$Salinity == sal.lvl[ii] & dens.col$Temperature == temp.lvl[jj],]
		tmp.trait <- trait.col[trait.col$Salinity == sal.lvl[ii] & trait.col$Temperature == temp.lvl[jj],]

		rep.lvl <- unique(tmp.dens$Replicate)
		nr. <- length(unique(tmp.dens$Replicate))
		ccm.area.col.list[[kk]] <- rep(NA, 10*nr.+nr.)
		ccm.dens.col.list[[kk]] <- rep(NA, 10*nr.+nr.)
	
		for(rr in 1:nr.){	
			tmp.rep <- tmp.dens[tmp.dens$Replicate == rep.lvl[rr],]
			pos.11 <- which(as.numeric(as.character(tmp.rep$act.time)) > 12)
			if(length(pos.11) != 0){
				dd. <- tmp.rep$density[-pos.11]
			} else {
				dd. <- tmp.rep$density
			}

			ccm.dens.col.list[[kk]][(rr+1+10*(rr-1)):(rr+10+10*(rr-1))][1:length(dd.)] <- dd.
			
			tmp2.rep <- tmp.trait[tmp.trait$Replicate == rep.lvl[rr],]
			pos2.11 <- which(as.numeric(as.character(tmp2.rep$act.time)) > 12)
			if(length(pos.11) != 0){
				dd2. <- tmp2.rep$mean_area[-pos.11]
			} else {
				dd2. <- tmp2.rep$mean_area
			}

			ccm.area.col.list[[kk]][(rr+1+10*(rr-1)):(rr+10+10*(rr-1))][1:length(dd2.)] <- dd2.
		}
		kk <- kk + 1
	}
}			

## Each replicate needs to be separated by an 'NA'
## check if some have two NA's

ccm.dens.col.list

## Find embedding dimension
maxE <- 6
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('dens.col', 'area.col')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'dens.col'] <- SSR_pred_boot(A = ccm.dens.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'area.col'] <- SSR_pred_boot(A = ccm.area.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('dens', 'area'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_dens <- c(5, 6, 6, 4, 6, 4, 3, 4, 4, 4, 5, 5)
E_area <- c(2, 2, 2, 3, 2, 2, 2, 2, 2, 2, 3, 5)

#E_dens <- rep(5.2, 12) 
#E_area <- rep(2.8, 12)

#E_dens <- rep(4, 12) 
#E_area <- rep(4, 12) 


## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.dens.col.list[[kk]], ccm.area.col.list[[kk]], E_dens[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.area.col.list[[kk]], ccm.dens.col.list[[kk]], E_area[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))
for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	## the actual plotting	
	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3,48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('dens causes area', 'area causes dens'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}

## finding a threshold 
dif.A <- dif.B <- relsd.A <- relsd.B <- vector()
for(kk in 1:12){
	dif.A <- append(dif.A, CCM_boot_A[[kk]]$rho[length(CCM_boot_A[[kk]]$rho)] - CCM_boot_A[[kk]]$rho[1])
	relsd.A <- append(relsd.A, CCM_boot_A[[kk]]$sdevrho[length(CCM_boot_A[[kk]]$sdevrho)]/CCM_boot_A[[kk]]$sdevrho[1])
	dif.B <- append(dif.B, CCM_boot_B[[kk]]$rho[length(CCM_boot_B[[kk]]$rho)] - CCM_boot_B[[kk]]$rho[1])
	relsd.B <- append(relsd.B, CCM_boot_B[[kk]]$sdevrho[length(CCM_boot_B[[kk]]$sdevrho)]/CCM_boot_B[[kk]]$sdevrho[1])
}

col.temp <- c('blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red')
cex. = c(1,1,1,1,2,2,2,2,3,3,3,3)
plot(c(relsd.A, relsd.B), c(dif.A, dif.B), type = 'n', xlim = c(0, 1.2), ylim = c(-0.2, 0.6))
points(relsd.A, dif.A, pch = 21, cex = cex., col = col.temp)
points(relsd.B, dif.B, pch = 22, cex = cex., col = col.temp)



col.temp <- c('blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red')
plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'colpidium mono')

for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}
	




## 1b. Colpidium in competition
## Prepare data for CCM
ccm.areaPC.col.list <- ccm.densPC.col.list <- list()

## We will not focus on salinity 3
kk <- 1
for(ii in 1:3){
	for(jj in 1:4){
		tmp.dens <- densPC.col[densPC.col$Salinity == sal.lvl[ii] & densPC.col$Temperature == temp.lvl[jj],]
		tmp.trait <- traitPC.col[traitPC.col$Salinity == sal.lvl[ii] & traitPC.col$Temperature == temp.lvl[jj],]

		rep.lvl <- unique(tmp.dens$Replicate)
		nr. <- length(unique(tmp.dens$Replicate))
		ccm.areaPC.col.list[[kk]] <- rep(NA, 13*nr.+nr.)
		ccm.densPC.col.list[[kk]] <- rep(NA, 13*nr.+nr.)
	
		for(rr in 1:nr.){	
			tmp.rep <- tmp.dens[tmp.dens$Replicate == rep.lvl[rr],]
			#pos.11 <- which(as.numeric(as.character(tmp.rep$act.time)) > 12)
			#if(length(pos.11) != 0){
			#	dd. <- tmp.rep$density[-pos.11]
			#} else {
				dd. <- tmp.rep$density
			#}

			ccm.densPC.col.list[[kk]][(rr+1+13*(rr-1)):(rr+13+13*(rr-1))][1:length(dd.)] <- dd.
			
			tmp2.rep <- tmp.trait[tmp.trait$Replicate == rep.lvl[rr],]
			#pos2.11 <- which(as.numeric(as.character(tmp2.rep$act.time)) > 12)
			#if(length(pos.11) != 0){
			#	dd2. <- tmp2.rep$mean_area[-pos.11]
			#} else {
				dd2. <- tmp2.rep$mean_area
			#}

			ccm.areaPC.col.list[[kk]][(rr+1+13*(rr-1)):(rr+13+13*(rr-1))][1:length(dd2.)] <- dd2.
		}
		kk <- kk + 1
	}
}			

## Each replicate needs to be separated by an 'NA'
## check if some have two NA's

ccm.dens.col.list

## Find embedding dimension
maxE <- 8
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('dens.col', 'area.col')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'dens.col'] <- SSR_pred_boot(A = ccm.densPC.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'area.col'] <- SSR_pred_boot(A = ccm.areaPC.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('dens', 'area'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_densPC <- c(8, 6, 4, 4, 4, 5, 7, 5, 8, 7, 4, 6)
E_areaPC <- c(4, 4, 2, 2, 3, 5, 2, 5, 3, 3, 3, 3)

#E_densPC <- rep(5.2, 12)
#E_areaPC <- rep(2.8, 12)

#E_densPC <- rep(4, 12)
#E_areaPC <- rep(4, 12)


## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.densPC.col.list[[kk]], ccm.areaPC.col.list[[kk]], E_densPC[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.areaPC.col.list[[kk]], ccm.densPC.col.list[[kk]], E_areaPC[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))

for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3,48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('dens causes area', 'area causes dens'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}

## finding a threshold 
dif.A <- dif.B <- relsd.A <- relsd.B <- vector()
for(kk in 1:12){
	dif.A <- append(dif.A, CCM_boot_A[[kk]]$rho[length(CCM_boot_A[[kk]]$rho)] - CCM_boot_A[[kk]]$rho[1])
	relsd.A <- append(relsd.A, CCM_boot_A[[kk]]$sdevrho[length(CCM_boot_A[[kk]]$sdevrho)]/CCM_boot_A[[kk]]$sdevrho[1])
	dif.B <- append(dif.B, CCM_boot_B[[kk]]$rho[length(CCM_boot_B[[kk]]$rho)] - CCM_boot_B[[kk]]$rho[1])
	relsd.B <- append(relsd.B, CCM_boot_B[[kk]]$sdevrho[length(CCM_boot_B[[kk]]$sdevrho)]/CCM_boot_B[[kk]]$sdevrho[1])
}

col.temp <- c('blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red')
plot(c(relsd.A, relsd.B), c(dif.A, dif.B), type = 'n', xlim = c(0, 1.2), ylim = c(-0.2, 0.6))
points(relsd.A, dif.A, pch = 21, cex = cex., col = col.temp)
points(relsd.B, dif.B, pch = 22, cex = cex., col = col.temp)


plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'colpidium comp')
for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}


## Prepare data for CCM
ccm.area.pau.list <- ccm.dens.pau.list <- list()

## we need to limit to certain time points still!!! 
## if we do not have density at all time points... at least in the beginning

## 1. Paramecium in monoculture
## We will not focus on salinity 3
kk <- 1
for(ii in 1:3){
	for(jj in 1:4){
		tmp.dens <- dens.pau[dens.pau$Salinity == sal.lvl[ii] & dens.pau$Temperature == temp.lvl[jj],]
		tmp.trait <- trait.pau[trait.pau$Salinity == sal.lvl[ii] & trait.pau$Temperature == temp.lvl[jj],]

		rep.lvl <- unique(tmp.dens$Replicate)
		nr. <- length(unique(tmp.dens$Replicate))
		ccm.area.pau.list[[kk]] <- rep(NA, 10*nr.+nr.)
		ccm.dens.pau.list[[kk]] <- rep(NA, 10*nr.+nr.)
	
		for(rr in 1:nr.){	
			tmp.rep <- tmp.dens[tmp.dens$Replicate == rep.lvl[rr],]
			pos.11 <- which(as.numeric(as.character(tmp.rep$act.time)) > 12)
			if(length(pos.11) != 0){
				dd. <- tmp.rep$density[-pos.11]
			} else {
				dd. <- tmp.rep$density
			}

			ccm.dens.pau.list[[kk]][(rr+1+10*(rr-1)):(rr+10+10*(rr-1))][1:length(dd.)] <- dd.
			
			tmp2.rep <- tmp.trait[tmp.trait$Replicate == rep.lvl[rr],]
			pos2.11 <- which(as.numeric(as.character(tmp2.rep$act.time)) > 12)
			if(length(pos.11) != 0){
				dd2. <- tmp2.rep$mean_area[-pos.11]
			} else {
				dd2. <- tmp2.rep$mean_area
			}

			ccm.area.pau.list[[kk]][(rr+1+10*(rr-1)):(rr+10+10*(rr-1))][1:length(dd2.)] <- dd2.
		}
		kk <- kk + 1
	}
}			

## Each replicate needs to be separated by an 'NA'
## check if some have two NA's

## Find embedding dimension
maxE <- 6
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('dens.pau', 'area.pau')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'dens.pau'] <- SSR_pred_boot(A = ccm.dens.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'area.pau'] <- SSR_pred_boot(A = ccm.area.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('dens', 'area'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_dens <- c(2, 6, 4, 6, 5, 5, 6, 6, 2, 6, 6, 6)
E_area <- c(2, 3, 2, 3, 3, 6, 2, 2, 2, 3, 2, 2)

#E_dens <- c(rep(5.4, 8), 2, rep(5.4, 3))
#E_area <- rep(3, 12)

#E_dens <- rep(4, 12) 
#E_area <- rep(4, 12) 


## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.dens.pau.list[[kk]], ccm.area.pau.list[[kk]], E_dens[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.area.pau.list[[kk]], ccm.dens.pau.list[[kk]], E_area[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))
for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3,48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('dens causes area', 'area causes dens'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}



## finding a threshold 
dif.A <- dif.B <- relsd.A <- relsd.B <- vector()
for(kk in 1:12){
	dif.A <- append(dif.A, CCM_boot_A[[kk]]$rho[length(CCM_boot_A[[kk]]$rho)] - CCM_boot_A[[kk]]$rho[1])
	relsd.A <- append(relsd.A, CCM_boot_A[[kk]]$sdevrho[length(CCM_boot_A[[kk]]$sdevrho)]/CCM_boot_A[[kk]]$sdevrho[1])
	dif.B <- append(dif.B, CCM_boot_B[[kk]]$rho[length(CCM_boot_B[[kk]]$rho)] - CCM_boot_B[[kk]]$rho[1])
	relsd.B <- append(relsd.B, CCM_boot_B[[kk]]$sdevrho[length(CCM_boot_B[[kk]]$sdevrho)]/CCM_boot_B[[kk]]$sdevrho[1])
}

col.temp <- c('blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red')
plot(c(relsd.A, relsd.B), c(dif.A, dif.B), type = 'n', xlim = c(0, 1.2), ylim = c(-0.2, 0.6))
points(relsd.A, dif.A, pch = 21, cex = cex., col = col.temp)
points(relsd.B, dif.B, pch = 22, cex = cex., col = col.temp)


plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'paramecium mono')
for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}


## 1b. paramecium in competition
## Prepare data for CCM
ccm.areaPC.pau.list <- ccm.densPC.pau.list <- list()

## We will not focus on salinity 3
kk <- 1
for(ii in 1:3){
	for(jj in 1:4){
		tmp.dens <- densPC.pau[densPC.pau$Salinity == sal.lvl[ii] & densPC.pau$Temperature == temp.lvl[jj],]
		tmp.trait <- traitPC.pau[traitPC.pau$Salinity == sal.lvl[ii] & traitPC.pau$Temperature == temp.lvl[jj],]

		rep.lvl <- unique(tmp.dens$Replicate)
		nr. <- length(unique(tmp.dens$Replicate))
		ccm.areaPC.pau.list[[kk]] <- rep(NA, 13*nr.+nr.)
		ccm.densPC.pau.list[[kk]] <- rep(NA, 13*nr.+nr.)
	
		for(rr in 1:nr.){	
			tmp.rep <- tmp.dens[tmp.dens$Replicate == rep.lvl[rr],]
			#pos.11 <- which(as.numeric(as.character(tmp.rep$act.time)) > 12)
			#if(length(pos.11) != 0){
			#	dd. <- tmp.rep$density[-pos.11]
			#} else {
				dd. <- tmp.rep$density
			#}

			ccm.densPC.pau.list[[kk]][(rr+1+13*(rr-1)):(rr+13+13*(rr-1))][1:length(dd.)] <- dd.
			
			tmp2.rep <- tmp.trait[tmp.trait$Replicate == rep.lvl[rr],]
			#pos2.11 <- which(as.numeric(as.character(tmp2.rep$act.time)) > 12)
			#if(length(pos.11) != 0){
			#	dd2. <- tmp2.rep$mean_area[-pos.11]
			#} else {
				dd2. <- tmp2.rep$mean_area
			#}

			ccm.areaPC.pau.list[[kk]][(rr+1+13*(rr-1)):(rr+13+13*(rr-1))][1:length(dd2.)] <- dd2.
		}
		kk <- kk + 1
	}
}			

## Each replicate needs to be separated by an 'NA'
## check if some have two NA's

ccm.dens.col.list

## Find embedding dimension
maxE <- 8
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('dens.pau', 'area.pau')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'dens.pau'] <- SSR_pred_boot(A = ccm.densPC.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'area.pau'] <- SSR_pred_boot(A = ccm.areaPC.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('dens', 'area'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_densPC <- c(6, 8, 8, 8, 3, 8, 4, 6, 2, 8, 3, 4)
E_areaPC <- c(7, 2, 3, 3, 4, 2, 2, 2, 3, 2, 3, 6)

#E_densPC <- rep(5.4, 12)
#E_areaPC <- rep(3, 12)

#E_densPC <- rep(5, 12)
#E_areaPC <- rep(4, 12)



## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.densPC.pau.list[[kk]], ccm.areaPC.pau.list[[kk]], E_densPC[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.areaPC.pau.list[[kk]], ccm.densPC.pau.list[[kk]], E_areaPC[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))

for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3, 48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('dens causes area', 'area causes dens'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}

## finding a threshold 
dif.A <- dif.B <- relsd.A <- relsd.B <- vector()
for(kk in 1:12){
	dif.A <- append(dif.A, CCM_boot_A[[kk]]$rho[length(CCM_boot_A[[kk]]$rho)] - CCM_boot_A[[kk]]$rho[1])
	relsd.A <- append(relsd.A, CCM_boot_A[[kk]]$sdevrho[length(CCM_boot_A[[kk]]$sdevrho)]/CCM_boot_A[[kk]]$sdevrho[1])
	dif.B <- append(dif.B, CCM_boot_B[[kk]]$rho[length(CCM_boot_B[[kk]]$rho)] - CCM_boot_B[[kk]]$rho[1])
	relsd.B <- append(relsd.B, CCM_boot_B[[kk]]$sdevrho[length(CCM_boot_B[[kk]]$sdevrho)]/CCM_boot_B[[kk]]$sdevrho[1])
}

col.temp <- c('blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red', 'blue', 'lightblue', 'pink', 'red')
plot(c(relsd.A, relsd.B), c(dif.A, dif.B), type = 'n', xlim = c(0, 1.2), ylim = c(-0.2, 0.6))
points(relsd.A, dif.A, pch = 21, cex = cex., col = col.temp)
points(relsd.B, dif.B, pch = 22, cex = cex., col = col.temp)


plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'paramecium comp')
for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}

## ---------------------------------------------------------------------------
## Convergent cross cross mapping competition across species
## ---------------------------------------------------------------------------

## Effects of densities of Paramecium and Colpidium

## 1b. paramecium in competition
## Prepare data for CCM
ccm.areaPC.pau.list 
ccm.densPC.pau.list
ccm.areaPC.col.list
ccm.densPC.col.list


## Find embedding dimension
maxE <- 9
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('dens.pau', 'dens.col')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'dens.pau'] <- SSR_pred_boot(A = ccm.densPC.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'dens.col'] <- SSR_pred_boot(A = ccm.densPC.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('dens.pau', 'dens.col'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_densPC.pau <- c(9, 8, 8, 8, 3, 9, 8, 9, 2, 8, 3, 4)
E_densPC.col <- c(9, 6, 4, 4, 4, 5, 7, 5, 8, 7, 4, 6)

#E_densPC.pau <- rep(4, 12)
#E_densPC.col <- rep(4, 12)


## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.densPC.pau.list[[kk]], ccm.densPC.col.list[[kk]], E_densPC.pau[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.densPC.col.list[[kk]], ccm.densPC.pau.list[[kk]], E_densPC.col[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))

for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3, 48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('pau dens causes col dens', 'col dens causes pau dens'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}

plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'paramecium dens colp dens')
for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}


## density and traits


## Find embedding dimension
maxE <- 9
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('dens.pau', 'area.col')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'dens.pau'] <- SSR_pred_boot(A = ccm.densPC.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'area.col'] <- SSR_pred_boot(A = ccm.areaPC.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('dens.pau', 'area.col'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_densPC.pau <- c(9, 8, 8, 8, 3, 9, 8, 9, 2, 8, 4, 4)
E_areaPC.col <- c(2, 4, 2, 2, 2, 5, 2, 5, 3, 3, 2, 3)

#E_densPC.pau <- rep(4, 12)
#E_areaPC.col <- rep(4, 12)

## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.densPC.pau.list[[kk]], ccm.areaPC.col.list[[kk]], E_densPC.pau[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.areaPC.col.list[[kk]], ccm.densPC.pau.list[[kk]], E_areaPC.col[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))

for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3, 48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('pau dens causes col area', 'col area causes pau dens'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}

plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'paramecium dens colp area')
for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}




## Find embedding dimension
maxE <- 9
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('area.pau', 'dens.col')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'area.pau'] <- SSR_pred_boot(A = ccm.areaPC.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'dens.col'] <- SSR_pred_boot(A = ccm.densPC.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('area.pau', 'dens.col'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_areaPC.pau <- c(7, 2, 3, 3, 4, 2, 2, 3, 3, 2, 3, 6)
E_densPC.col <- c(9, 6, 4, 4, 4, 5, 7, 5, 8, 7, 4, 6)

#E_areaPC.pau <- rep(4, 12)
#E_densPC.col <- rep(4, 12)

## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.areaPC.pau.list[[kk]], ccm.densPC.col.list[[kk]], E_areaPC.pau[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.densPC.col.list[[kk]], ccm.areaPC.pau.list[[kk]], E_densPC.col[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))

for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3, 48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('pau area causes col dens', 'col dens causes pau area'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}


plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'paramecium area colp dens')
for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 21, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 21, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}


## traits and traits

## Find embedding dimension
maxE <- 9
Emat <- list()

for(kk in 1:12){
	Emat[[kk]] <- matrix(nrow = maxE - 1, ncol = 2)
	colnames(Emat[[kk]]) <- c('area.pau', 'area.col')

	for(E in 2:maxE){
		Emat[[kk]][E-1, 'area.pau'] <- SSR_pred_boot(A = ccm.areaPC.pau.list[[kk]], E = E, predstep = 1, tau = 1)$rho
		Emat[[kk]][E-1, 'area.col'] <- SSR_pred_boot(A = ccm.areaPC.col.list[[kk]], E = E, predstep = 1, tau = 1)$rho
	}
}

## Plot to find E at which predictive ability rho is maximized
par(mfrow = c(3,4))
for(kk in 1:12){
	matplot(2:maxE, Emat[[kk]], type = 'l', col = 1:2, lty = 1:2, xlab = 'E', ylab = 'rho', lwd = 2)
	legend('bottomleft', c('area.pau', 'area.col'), lty = 1:2, col = 1:2, lwd = 2, bty = 'n')
}

## Based on the plots, we choose
E_areaPC.pau <- c(7, 2, 3, 3, 4, 2, 2, 3, 3, 2, 3, 6)
E_areaPC.col <- c(2, 3, 2, 2, 3, 5, 2, 5, 3, 3, 2, 3)

#E_areaPC.pau <- rep(4, 12)
#E_areaPC.col <- rep(4, 12)

## Run the CCM test
CCM_boot_A <- CCM_boot_B <- list()
for(kk in 1:12){
	## Does density cause area?
	CCM_boot_A[[kk]] <- CCM_boot(ccm.areaPC.pau.list[[kk]], ccm.areaPC.col.list[[kk]], E_areaPC.pau[kk], tau = 1, iterations = 800)
	## Does area cause density?
	CCM_boot_B[[kk]] <- CCM_boot(ccm.areaPC.col.list[[kk]], ccm.areaPC.pau.list[[kk]], E_areaPC.col[kk], tau = 1, iterations = 800)
}

## plot results
dev.new(height = 5, width = 18)
par(mfrow = c(1,4))

par(mfrow = c(3,4))

for(kk in 1:12){

	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}

	x.lim <- range(c(CCM_boot_A[[kk]]$Lobs, CCM_boot_B[[kk]]$Lobs))
	plot(CCM_boot_A[[kk]]$Lobs, CCM_boot_A[[kk]]$rho, type = 'l', col = 1, lwd =2, xlim = c(3, 48), ylim = c(0,1), xlab = 'L', ylab = 'rho', main = 'dens cause area')
	lines(CCM_boot_B[[kk]]$Lobs, CCM_boot_B[[kk]]$rho, type = 'l', col = 2, lty = 1, lwd = 2)
	#matlines(CCM_boot_A[[kk]]$Lobs, cbind(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho), lty = 1, col = 1)
	polygon(c(CCM_boot_A[[kk]]$Lobs, rev(CCM_boot_A[[kk]]$Lobs)), c(CCM_boot_A[[kk]]$rho - CCM_boot_A[[kk]]$sdevrho, rev(CCM_boot_A[[kk]]$rho + CCM_boot_A[[kk]]$sdevrho)), col = 'grey')
	#matlines(CCM_boot_B[[kk]]$Lobs, cbind(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho), lty = 1, col = 2)
	polygon(c(CCM_boot_B[[kk]]$Lobs, rev(CCM_boot_B[[kk]]$Lobs)), c(CCM_boot_B[[kk]]$rho - CCM_boot_B[[kk]]$sdevrho, rev(CCM_boot_B[[kk]]$rho + CCM_boot_B[[kk]]$sdevrho)), col = 'red')
	legend('topleft', c('pau area causes col area', 'col area causes pau area'), lty = c(1,2), col = c(1,2), lwd = 2, bty = 'n')

}

plot(-100, -100, xlim = c(0, 12), ylim = c(0,1), type = 'n', main = 'paramecium area colp area')
for(kk in 1:12){
	## Values that are below zero should be set to zero
	zero.A <- which(CCM_boot_A[[kk]]$rho < 0)
	zero.B <- which(CCM_boot_B[[kk]]$rho < 0)

	if(length(zero.A) != 0){
		CCM_boot_A[[kk]]$rho[zero.A] <- 0
	}
	if(length(zero.B) != 0){
		CCM_boot_B[[kk]]$rho[zero.B] <- 0
	}
	
	nr <- length(CCM_boot_A[[kk]]$rho)
	points(rep(kk, nr, factor = 5), CCM_boot_A[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk, CCM_boot_A[[kk]]$rho[nr], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk, CCM_boot_A[[kk]]$rho[nr] - CCM_boot_A[[kk]]$sdevrho[nr], kk, CCM_boot_A[[kk]]$rho[nr] + CCM_boot_A[[kk]]$sdevrho[nr], col = col.temp[[kk]])

	nrB <- length(CCM_boot_B[[kk]]$rho)
	points(rep(kk+0.2, nrB, factor = 5), CCM_boot_B[[kk]]$rho, pch = 22, cex = 1, col = col.temp[[kk]])
	points(kk+0.2, CCM_boot_B[[kk]]$rho[nrB], pch = 22, cex = 2, col = col.temp[[kk]])
	segments(kk+0.2, CCM_boot_B[[kk]]$rho[nrB] - CCM_boot_B[[kk]]$sdevrho[nrB], kk+0.2, CCM_boot_B[[kk]]$rho[nrB] + CCM_boot_B[[kk]]$sdevrho[nrB], col = col.temp[[kk]])
}







